class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QDesignerActionEditorInterface(QWidget):
    """"""
    def __init__(self, parent, flags = 0):
        '''void QDesignerActionEditorInterface.__init__(QWidget parent, Qt.WindowFlags flags = 0)'''
    def setFormWindow(self, formWindow):
        '''abstract void QDesignerActionEditorInterface.setFormWindow(QDesignerFormWindowInterface formWindow)'''
    def unmanageAction(self, action):
        '''abstract void QDesignerActionEditorInterface.unmanageAction(QAction action)'''
    def manageAction(self, action):
        '''abstract void QDesignerActionEditorInterface.manageAction(QAction action)'''
    def core(self):
        '''QDesignerFormEditorInterface QDesignerActionEditorInterface.core()'''
        return QDesignerFormEditorInterface()


class QAbstractFormBuilder():
    """"""
    def __init__(self):
        '''void QAbstractFormBuilder.__init__()'''
    def errorString(self):
        '''str QAbstractFormBuilder.errorString()'''
        return str()
    def workingDirectory(self):
        '''QDir QAbstractFormBuilder.workingDirectory()'''
        return QDir()
    def setWorkingDirectory(self, directory):
        '''void QAbstractFormBuilder.setWorkingDirectory(QDir directory)'''
    def save(self, dev, widget):
        '''void QAbstractFormBuilder.save(QIODevice dev, QWidget widget)'''
    def load(self, device, parent = None):
        '''QWidget QAbstractFormBuilder.load(QIODevice device, QWidget parent = None)'''
        return QWidget()


class QDesignerFormEditorInterface(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QDesignerFormEditorInterface.__init__(QObject parent = None)'''
    def setActionEditor(self, actionEditor):
        '''void QDesignerFormEditorInterface.setActionEditor(QDesignerActionEditorInterface actionEditor)'''
    def setObjectInspector(self, objectInspector):
        '''void QDesignerFormEditorInterface.setObjectInspector(QDesignerObjectInspectorInterface objectInspector)'''
    def setPropertyEditor(self, propertyEditor):
        '''void QDesignerFormEditorInterface.setPropertyEditor(QDesignerPropertyEditorInterface propertyEditor)'''
    def setWidgetBox(self, widgetBox):
        '''void QDesignerFormEditorInterface.setWidgetBox(QDesignerWidgetBoxInterface widgetBox)'''
    def actionEditor(self):
        '''QDesignerActionEditorInterface QDesignerFormEditorInterface.actionEditor()'''
        return QDesignerActionEditorInterface()
    def formWindowManager(self):
        '''QDesignerFormWindowManagerInterface QDesignerFormEditorInterface.formWindowManager()'''
        return QDesignerFormWindowManagerInterface()
    def objectInspector(self):
        '''QDesignerObjectInspectorInterface QDesignerFormEditorInterface.objectInspector()'''
        return QDesignerObjectInspectorInterface()
    def propertyEditor(self):
        '''QDesignerPropertyEditorInterface QDesignerFormEditorInterface.propertyEditor()'''
        return QDesignerPropertyEditorInterface()
    def widgetBox(self):
        '''QDesignerWidgetBoxInterface QDesignerFormEditorInterface.widgetBox()'''
        return QDesignerWidgetBoxInterface()
    def topLevel(self):
        '''QWidget QDesignerFormEditorInterface.topLevel()'''
        return QWidget()
    def extensionManager(self):
        '''QExtensionManager QDesignerFormEditorInterface.extensionManager()'''
        return QExtensionManager()


class QDesignerFormWindowInterface(QWidget):
    """"""
    # Enum QDesignerFormWindowInterface.FeatureFlag
    EditFeature = 0
    GridFeature = 0
    TabOrderFeature = 0
    DefaultFeature = 0

    def __init__(self, parent = None, flags = 0):
        '''void QDesignerFormWindowInterface.__init__(QWidget parent = None, Qt.WindowFlags flags = 0)'''
    def activateResourceFilePaths(self, paths, errorCount, errorMessages):
        '''void QDesignerFormWindowInterface.activateResourceFilePaths(list-of-str paths, int errorCount, str errorMessages)'''
    def formContainer(self):
        '''abstract QWidget QDesignerFormWindowInterface.formContainer()'''
        return QWidget()
    def activeResourceFilePaths(self):
        '''list-of-str QDesignerFormWindowInterface.activeResourceFilePaths()'''
        return [str()]
    def checkContents(self):
        '''abstract list-of-str QDesignerFormWindowInterface.checkContents()'''
        return [str()]
    objectRemoved = pyqtSignal() # void objectRemoved(QObject*) - signal
    widgetRemoved = pyqtSignal() # void widgetRemoved(QWidget*) - signal
    changed = pyqtSignal() # void changed() - signal
    activated = pyqtSignal() # void activated(QWidget*) - signal
    aboutToUnmanageWidget = pyqtSignal() # void aboutToUnmanageWidget(QWidget*) - signal
    widgetUnmanaged = pyqtSignal() # void widgetUnmanaged(QWidget*) - signal
    widgetManaged = pyqtSignal() # void widgetManaged(QWidget*) - signal
    resourceFilesChanged = pyqtSignal() # void resourceFilesChanged() - signal
    geometryChanged = pyqtSignal() # void geometryChanged() - signal
    selectionChanged = pyqtSignal() # void selectionChanged() - signal
    featureChanged = pyqtSignal() # void featureChanged(QDesignerFormWindowInterface::Feature) - signal
    fileNameChanged = pyqtSignal() # void fileNameChanged(const QStringamp;) - signal
    mainContainerChanged = pyqtSignal() # void mainContainerChanged(QWidget*) - signal
    def setFileName(self, fileName):
        '''abstract void QDesignerFormWindowInterface.setFileName(str fileName)'''
    def setGrid(self, grid):
        '''abstract void QDesignerFormWindowInterface.setGrid(QPoint grid)'''
    def selectWidget(self, widget, select = True):
        '''abstract void QDesignerFormWindowInterface.selectWidget(QWidget widget, bool select = True)'''
    def clearSelection(self, update = True):
        '''abstract void QDesignerFormWindowInterface.clearSelection(bool update = True)'''
    def setDirty(self, dirty):
        '''abstract void QDesignerFormWindowInterface.setDirty(bool dirty)'''
    def setFeatures(self, f):
        '''abstract void QDesignerFormWindowInterface.setFeatures(QDesignerFormWindowInterface.Feature f)'''
    def unmanageWidget(self, widget):
        '''abstract void QDesignerFormWindowInterface.unmanageWidget(QWidget widget)'''
    def manageWidget(self, widget):
        '''abstract void QDesignerFormWindowInterface.manageWidget(QWidget widget)'''
    def removeResourceFile(self, path):
        '''abstract void QDesignerFormWindowInterface.removeResourceFile(str path)'''
    def addResourceFile(self, path):
        '''abstract void QDesignerFormWindowInterface.addResourceFile(str path)'''
    def resourceFiles(self):
        '''abstract list-of-str QDesignerFormWindowInterface.resourceFiles()'''
        return [str()]
    def emitSelectionChanged(self):
        '''abstract void QDesignerFormWindowInterface.emitSelectionChanged()'''
    def findFormWindow(self, w):
        '''static QDesignerFormWindowInterface QDesignerFormWindowInterface.findFormWindow(QWidget w)'''
        return QDesignerFormWindowInterface()
    def findFormWindow(self, obj):
        '''static QDesignerFormWindowInterface QDesignerFormWindowInterface.findFormWindow(QObject obj)'''
        return QDesignerFormWindowInterface()
    def isDirty(self):
        '''abstract bool QDesignerFormWindowInterface.isDirty()'''
        return bool()
    def isManaged(self, widget):
        '''abstract bool QDesignerFormWindowInterface.isManaged(QWidget widget)'''
        return bool()
    def setMainContainer(self, mainContainer):
        '''abstract void QDesignerFormWindowInterface.setMainContainer(QWidget mainContainer)'''
    def mainContainer(self):
        '''abstract QWidget QDesignerFormWindowInterface.mainContainer()'''
        return QWidget()
    def grid(self):
        '''abstract QPoint QDesignerFormWindowInterface.grid()'''
        return QPoint()
    def cursor(self):
        '''abstract QDesignerFormWindowCursorInterface QDesignerFormWindowInterface.cursor()'''
        return QDesignerFormWindowCursorInterface()
    def core(self):
        '''QDesignerFormEditorInterface QDesignerFormWindowInterface.core()'''
        return QDesignerFormEditorInterface()
    def setIncludeHints(self, includeHints):
        '''abstract void QDesignerFormWindowInterface.setIncludeHints(list-of-str includeHints)'''
    def includeHints(self):
        '''abstract list-of-str QDesignerFormWindowInterface.includeHints()'''
        return [str()]
    def setExportMacro(self, exportMacro):
        '''abstract void QDesignerFormWindowInterface.setExportMacro(str exportMacro)'''
    def exportMacro(self):
        '''abstract str QDesignerFormWindowInterface.exportMacro()'''
        return str()
    def setPixmapFunction(self, pixmapFunction):
        '''abstract void QDesignerFormWindowInterface.setPixmapFunction(str pixmapFunction)'''
    def pixmapFunction(self):
        '''abstract str QDesignerFormWindowInterface.pixmapFunction()'''
        return str()
    def setLayoutFunction(self, margin, spacing):
        '''abstract void QDesignerFormWindowInterface.setLayoutFunction(str margin, str spacing)'''
    def layoutFunction(self, margin, spacing):
        '''abstract void QDesignerFormWindowInterface.layoutFunction(str margin, str spacing)'''
    def setLayoutDefault(self, margin, spacing):
        '''abstract void QDesignerFormWindowInterface.setLayoutDefault(int margin, int spacing)'''
    def layoutDefault(self, margin, spacing):
        '''abstract void QDesignerFormWindowInterface.layoutDefault(int margin, int spacing)'''
    def setComment(self, comment):
        '''abstract void QDesignerFormWindowInterface.setComment(str comment)'''
    def comment(self):
        '''abstract str QDesignerFormWindowInterface.comment()'''
        return str()
    def setAuthor(self, author):
        '''abstract void QDesignerFormWindowInterface.setAuthor(str author)'''
    def author(self):
        '''abstract str QDesignerFormWindowInterface.author()'''
        return str()
    def hasFeature(self, f):
        '''abstract bool QDesignerFormWindowInterface.hasFeature(QDesignerFormWindowInterface.Feature f)'''
        return bool()
    def features(self):
        '''abstract QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.features()'''
        return QDesignerFormWindowInterface.Feature()
    def setContents(self, dev, errorMessage = None):
        '''abstract bool QDesignerFormWindowInterface.setContents(QIODevice dev, str errorMessage = None)'''
        return bool()
    def setContents(self, contents):
        '''abstract bool QDesignerFormWindowInterface.setContents(str contents)'''
        return bool()
    def contents(self):
        '''abstract str QDesignerFormWindowInterface.contents()'''
        return str()
    def absoluteDir(self):
        '''abstract QDir QDesignerFormWindowInterface.absoluteDir()'''
        return QDir()
    def fileName(self):
        '''abstract str QDesignerFormWindowInterface.fileName()'''
        return str()
    class Feature():
        """"""
        def __init__(self):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__init__()'''
            return QDesignerFormWindowInterface.Feature()
        def __init__(self):
            '''int QDesignerFormWindowInterface.Feature.__init__()'''
            return int()
        def __init__(self):
            '''void QDesignerFormWindowInterface.Feature.__init__()'''
        def __bool__(self):
            '''int QDesignerFormWindowInterface.Feature.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QDesignerFormWindowInterface.Feature.__ne__(QDesignerFormWindowInterface.Feature f)'''
            return bool()
        def __eq__(self, f):
            '''bool QDesignerFormWindowInterface.Feature.__eq__(QDesignerFormWindowInterface.Feature f)'''
            return bool()
        def __invert__(self):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__invert__()'''
            return QDesignerFormWindowInterface.Feature()
        def __and__(self, mask):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__and__(int mask)'''
            return QDesignerFormWindowInterface.Feature()
        def __xor__(self, f):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__xor__(QDesignerFormWindowInterface.Feature f)'''
            return QDesignerFormWindowInterface.Feature()
        def __xor__(self, f):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__xor__(int f)'''
            return QDesignerFormWindowInterface.Feature()
        def __or__(self, f):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__or__(QDesignerFormWindowInterface.Feature f)'''
            return QDesignerFormWindowInterface.Feature()
        def __or__(self, f):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__or__(int f)'''
            return QDesignerFormWindowInterface.Feature()
        def __int__(self):
            '''int QDesignerFormWindowInterface.Feature.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__ixor__(QDesignerFormWindowInterface.Feature f)'''
            return QDesignerFormWindowInterface.Feature()
        def __ior__(self, f):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__ior__(QDesignerFormWindowInterface.Feature f)'''
            return QDesignerFormWindowInterface.Feature()
        def __iand__(self, mask):
            '''QDesignerFormWindowInterface.Feature QDesignerFormWindowInterface.Feature.__iand__(int mask)'''
            return QDesignerFormWindowInterface.Feature()


class QDesignerFormWindowCursorInterface():
    """"""
    # Enum QDesignerFormWindowCursorInterface.MoveMode
    MoveAnchor = 0
    KeepAnchor = 0

    # Enum QDesignerFormWindowCursorInterface.MoveOperation
    NoMove = 0
    Start = 0
    End = 0
    Next = 0
    Prev = 0
    Left = 0
    Right = 0
    Up = 0
    Down = 0

    def __init__(self):
        '''void QDesignerFormWindowCursorInterface.__init__()'''
    def __init__(self):
        '''QDesignerFormWindowCursorInterface QDesignerFormWindowCursorInterface.__init__()'''
        return QDesignerFormWindowCursorInterface()
    def isWidgetSelected(self, widget):
        '''bool QDesignerFormWindowCursorInterface.isWidgetSelected(QWidget widget)'''
        return bool()
    def resetWidgetProperty(self, widget, name):
        '''abstract void QDesignerFormWindowCursorInterface.resetWidgetProperty(QWidget widget, str name)'''
    def setWidgetProperty(self, widget, name, value):
        '''abstract void QDesignerFormWindowCursorInterface.setWidgetProperty(QWidget widget, str name, QVariant value)'''
    def setProperty(self, name, value):
        '''abstract void QDesignerFormWindowCursorInterface.setProperty(str name, QVariant value)'''
    def selectedWidget(self, index):
        '''abstract QWidget QDesignerFormWindowCursorInterface.selectedWidget(int index)'''
        return QWidget()
    def selectedWidgetCount(self):
        '''abstract int QDesignerFormWindowCursorInterface.selectedWidgetCount()'''
        return int()
    def hasSelection(self):
        '''abstract bool QDesignerFormWindowCursorInterface.hasSelection()'''
        return bool()
    def widget(self, index):
        '''abstract QWidget QDesignerFormWindowCursorInterface.widget(int index)'''
        return QWidget()
    def widgetCount(self):
        '''abstract int QDesignerFormWindowCursorInterface.widgetCount()'''
        return int()
    def current(self):
        '''abstract QWidget QDesignerFormWindowCursorInterface.current()'''
        return QWidget()
    def setPosition(self, pos, mode = None):
        '''abstract void QDesignerFormWindowCursorInterface.setPosition(int pos, QDesignerFormWindowCursorInterface.MoveMode mode = QDesignerFormWindowCursorInterface.MoveAnchor)'''
    def position(self):
        '''abstract int QDesignerFormWindowCursorInterface.position()'''
        return int()
    def movePosition(self, op, mode = None):
        '''abstract bool QDesignerFormWindowCursorInterface.movePosition(QDesignerFormWindowCursorInterface.MoveOperation op, QDesignerFormWindowCursorInterface.MoveMode mode = QDesignerFormWindowCursorInterface.MoveAnchor)'''
        return bool()
    def formWindow(self):
        '''abstract QDesignerFormWindowInterface QDesignerFormWindowCursorInterface.formWindow()'''
        return QDesignerFormWindowInterface()


class QDesignerFormWindowManagerInterface(QObject):
    """"""
    # Enum QDesignerFormWindowManagerInterface.ActionGroup
    StyledPreviewActionGroup = 0

    # Enum QDesignerFormWindowManagerInterface.Action
    CutAction = 0
    CopyAction = 0
    PasteAction = 0
    DeleteAction = 0
    SelectAllAction = 0
    LowerAction = 0
    RaiseAction = 0
    UndoAction = 0
    RedoAction = 0
    HorizontalLayoutAction = 0
    VerticalLayoutAction = 0
    SplitHorizontalAction = 0
    SplitVerticalAction = 0
    GridLayoutAction = 0
    FormLayoutAction = 0
    BreakLayoutAction = 0
    AdjustSizeAction = 0
    SimplifyLayoutAction = 0
    DefaultPreviewAction = 0
    FormWindowSettingsDialogAction = 0

    def __init__(self, parent = None):
        '''void QDesignerFormWindowManagerInterface.__init__(QObject parent = None)'''
    def showPluginDialog(self):
        '''abstract void QDesignerFormWindowManagerInterface.showPluginDialog()'''
    def closeAllPreviews(self):
        '''abstract void QDesignerFormWindowManagerInterface.closeAllPreviews()'''
    def showPreview(self):
        '''abstract void QDesignerFormWindowManagerInterface.showPreview()'''
    def actionGroup(self, actionGroup):
        '''abstract QActionGroup QDesignerFormWindowManagerInterface.actionGroup(QDesignerFormWindowManagerInterface.ActionGroup actionGroup)'''
        return QActionGroup()
    def action(self, action):
        '''abstract QAction QDesignerFormWindowManagerInterface.action(QDesignerFormWindowManagerInterface.Action action)'''
        return QAction()
    def setActiveFormWindow(self, formWindow):
        '''abstract void QDesignerFormWindowManagerInterface.setActiveFormWindow(QDesignerFormWindowInterface formWindow)'''
    def removeFormWindow(self, formWindow):
        '''abstract void QDesignerFormWindowManagerInterface.removeFormWindow(QDesignerFormWindowInterface formWindow)'''
    def addFormWindow(self, formWindow):
        '''abstract void QDesignerFormWindowManagerInterface.addFormWindow(QDesignerFormWindowInterface formWindow)'''
    formWindowSettingsChanged = pyqtSignal() # void formWindowSettingsChanged(QDesignerFormWindowInterface*) - signal
    activeFormWindowChanged = pyqtSignal() # void activeFormWindowChanged(QDesignerFormWindowInterface*) - signal
    formWindowRemoved = pyqtSignal() # void formWindowRemoved(QDesignerFormWindowInterface*) - signal
    formWindowAdded = pyqtSignal() # void formWindowAdded(QDesignerFormWindowInterface*) - signal
    def core(self):
        '''abstract QDesignerFormEditorInterface QDesignerFormWindowManagerInterface.core()'''
        return QDesignerFormEditorInterface()
    def createFormWindow(self, parent = None, flags = 0):
        '''abstract QDesignerFormWindowInterface QDesignerFormWindowManagerInterface.createFormWindow(QWidget parent = None, Qt.WindowFlags flags = 0)'''
        return QDesignerFormWindowInterface()
    def formWindow(self, index):
        '''abstract QDesignerFormWindowInterface QDesignerFormWindowManagerInterface.formWindow(int index)'''
        return QDesignerFormWindowInterface()
    def formWindowCount(self):
        '''abstract int QDesignerFormWindowManagerInterface.formWindowCount()'''
        return int()
    def activeFormWindow(self):
        '''abstract QDesignerFormWindowInterface QDesignerFormWindowManagerInterface.activeFormWindow()'''
        return QDesignerFormWindowInterface()
    def actionSimplifyLayout(self):
        '''QAction QDesignerFormWindowManagerInterface.actionSimplifyLayout()'''
        return QAction()
    def actionFormLayout(self):
        '''QAction QDesignerFormWindowManagerInterface.actionFormLayout()'''
        return QAction()


class QDesignerObjectInspectorInterface(QWidget):
    """"""
    def __init__(self, parent, flags = 0):
        '''void QDesignerObjectInspectorInterface.__init__(QWidget parent, Qt.WindowFlags flags = 0)'''
    def setFormWindow(self, formWindow):
        '''abstract void QDesignerObjectInspectorInterface.setFormWindow(QDesignerFormWindowInterface formWindow)'''
    def core(self):
        '''QDesignerFormEditorInterface QDesignerObjectInspectorInterface.core()'''
        return QDesignerFormEditorInterface()


class QDesignerPropertyEditorInterface(QWidget):
    """"""
    def __init__(self, parent, flags = 0):
        '''void QDesignerPropertyEditorInterface.__init__(QWidget parent, Qt.WindowFlags flags = 0)'''
    def setReadOnly(self, readOnly):
        '''abstract void QDesignerPropertyEditorInterface.setReadOnly(bool readOnly)'''
    def setPropertyValue(self, name, value, changed = True):
        '''abstract void QDesignerPropertyEditorInterface.setPropertyValue(str name, QVariant value, bool changed = True)'''
    def setObject(self, object):
        '''abstract void QDesignerPropertyEditorInterface.setObject(QObject object)'''
    propertyChanged = pyqtSignal() # void propertyChanged(const QStringamp;,const QVariantamp;) - signal
    def currentPropertyName(self):
        '''abstract str QDesignerPropertyEditorInterface.currentPropertyName()'''
        return str()
    def object(self):
        '''abstract QObject QDesignerPropertyEditorInterface.object()'''
        return QObject()
    def isReadOnly(self):
        '''abstract bool QDesignerPropertyEditorInterface.isReadOnly()'''
        return bool()
    def core(self):
        '''QDesignerFormEditorInterface QDesignerPropertyEditorInterface.core()'''
        return QDesignerFormEditorInterface()


class QDesignerWidgetBoxInterface(QWidget):
    """"""
    def __init__(self, parent = None, flags = 0):
        '''void QDesignerWidgetBoxInterface.__init__(QWidget parent = None, Qt.WindowFlags flags = 0)'''
    def save(self):
        '''abstract bool QDesignerWidgetBoxInterface.save()'''
        return bool()
    def load(self):
        '''abstract bool QDesignerWidgetBoxInterface.load()'''
        return bool()
    def fileName(self):
        '''abstract str QDesignerWidgetBoxInterface.fileName()'''
        return str()
    def setFileName(self, file_name):
        '''abstract void QDesignerWidgetBoxInterface.setFileName(str file_name)'''


class QDesignerContainerExtension():
    """"""
    def __init__(self):
        '''void QDesignerContainerExtension.__init__()'''
    def __init__(self):
        '''QDesignerContainerExtension QDesignerContainerExtension.__init__()'''
        return QDesignerContainerExtension()
    def canRemove(self, index):
        '''bool QDesignerContainerExtension.canRemove(int index)'''
        return bool()
    def canAddWidget(self):
        '''bool QDesignerContainerExtension.canAddWidget()'''
        return bool()
    def remove(self, index):
        '''abstract void QDesignerContainerExtension.remove(int index)'''
    def insertWidget(self, index, widget):
        '''abstract void QDesignerContainerExtension.insertWidget(int index, QWidget widget)'''
    def addWidget(self, widget):
        '''abstract void QDesignerContainerExtension.addWidget(QWidget widget)'''
    def setCurrentIndex(self, index):
        '''abstract void QDesignerContainerExtension.setCurrentIndex(int index)'''
    def currentIndex(self):
        '''abstract int QDesignerContainerExtension.currentIndex()'''
        return int()
    def widget(self, index):
        '''abstract QWidget QDesignerContainerExtension.widget(int index)'''
        return QWidget()
    def __len__(self):
        ''' QDesignerContainerExtension.__len__()'''
        return ()
    def count(self):
        '''abstract int QDesignerContainerExtension.count()'''
        return int()


class QDesignerCustomWidgetInterface():
    """"""
    def __init__(self):
        '''void QDesignerCustomWidgetInterface.__init__()'''
    def __init__(self):
        '''QDesignerCustomWidgetInterface QDesignerCustomWidgetInterface.__init__()'''
        return QDesignerCustomWidgetInterface()
    def codeTemplate(self):
        '''str QDesignerCustomWidgetInterface.codeTemplate()'''
        return str()
    def domXml(self):
        '''str QDesignerCustomWidgetInterface.domXml()'''
        return str()
    def initialize(self, core):
        '''void QDesignerCustomWidgetInterface.initialize(QDesignerFormEditorInterface core)'''
    def isInitialized(self):
        '''bool QDesignerCustomWidgetInterface.isInitialized()'''
        return bool()
    def createWidget(self, parent):
        '''abstract QWidget QDesignerCustomWidgetInterface.createWidget(QWidget parent)'''
        return QWidget()
    def isContainer(self):
        '''abstract bool QDesignerCustomWidgetInterface.isContainer()'''
        return bool()
    def icon(self):
        '''abstract QIcon QDesignerCustomWidgetInterface.icon()'''
        return QIcon()
    def includeFile(self):
        '''abstract str QDesignerCustomWidgetInterface.includeFile()'''
        return str()
    def whatsThis(self):
        '''abstract str QDesignerCustomWidgetInterface.whatsThis()'''
        return str()
    def toolTip(self):
        '''abstract str QDesignerCustomWidgetInterface.toolTip()'''
        return str()
    def group(self):
        '''abstract str QDesignerCustomWidgetInterface.group()'''
        return str()
    def name(self):
        '''abstract str QDesignerCustomWidgetInterface.name()'''
        return str()


class QDesignerCustomWidgetCollectionInterface():
    """"""
    def __init__(self):
        '''void QDesignerCustomWidgetCollectionInterface.__init__()'''
    def __init__(self):
        '''QDesignerCustomWidgetCollectionInterface QDesignerCustomWidgetCollectionInterface.__init__()'''
        return QDesignerCustomWidgetCollectionInterface()
    def customWidgets(self):
        '''abstract list-of-QDesignerCustomWidgetInterface QDesignerCustomWidgetCollectionInterface.customWidgets()'''
        return [QDesignerCustomWidgetInterface()]


class QAbstractExtensionFactory():
    """"""
    def __init__(self):
        '''void QAbstractExtensionFactory.__init__()'''
    def __init__(self):
        '''QAbstractExtensionFactory QAbstractExtensionFactory.__init__()'''
        return QAbstractExtensionFactory()
    def extension(self, object, iid):
        '''abstract QObject QAbstractExtensionFactory.extension(QObject object, str iid)'''
        return QObject()


class QExtensionFactory(QObject, QAbstractExtensionFactory):
    """"""
    def __init__(self, parent = None):
        '''void QExtensionFactory.__init__(QExtensionManager parent = None)'''
    def createExtension(self, object, iid, parent):
        '''QObject QExtensionFactory.createExtension(QObject object, str iid, QObject parent)'''
        return QObject()
    def extensionManager(self):
        '''QExtensionManager QExtensionFactory.extensionManager()'''
        return QExtensionManager()
    def extension(self, object, iid):
        '''QObject QExtensionFactory.extension(QObject object, str iid)'''
        return QObject()


class QAbstractExtensionManager():
    """"""
    def __init__(self):
        '''void QAbstractExtensionManager.__init__()'''
    def __init__(self):
        '''QAbstractExtensionManager QAbstractExtensionManager.__init__()'''
        return QAbstractExtensionManager()
    def extension(self, object, iid):
        '''abstract QObject QAbstractExtensionManager.extension(QObject object, str iid)'''
        return QObject()
    def unregisterExtensions(self, factory, iid):
        '''abstract void QAbstractExtensionManager.unregisterExtensions(QAbstractExtensionFactory factory, str iid)'''
    def registerExtensions(self, factory, iid):
        '''abstract void QAbstractExtensionManager.registerExtensions(QAbstractExtensionFactory factory, str iid)'''


class QFormBuilder(QAbstractFormBuilder):
    """"""
    def __init__(self):
        '''void QFormBuilder.__init__()'''
    def customWidgets(self):
        '''list-of-QDesignerCustomWidgetInterface QFormBuilder.customWidgets()'''
        return [QDesignerCustomWidgetInterface()]
    def setPluginPath(self, pluginPaths):
        '''void QFormBuilder.setPluginPath(list-of-str pluginPaths)'''
    def addPluginPath(self, pluginPath):
        '''void QFormBuilder.addPluginPath(str pluginPath)'''
    def clearPluginPaths(self):
        '''void QFormBuilder.clearPluginPaths()'''
    def pluginPaths(self):
        '''list-of-str QFormBuilder.pluginPaths()'''
        return [str()]


class QDesignerMemberSheetExtension():
    """"""
    def __init__(self):
        '''void QDesignerMemberSheetExtension.__init__()'''
    def __init__(self):
        '''QDesignerMemberSheetExtension QDesignerMemberSheetExtension.__init__()'''
        return QDesignerMemberSheetExtension()
    def parameterNames(self, index):
        '''abstract list-of-QByteArray QDesignerMemberSheetExtension.parameterNames(int index)'''
        return [QByteArray()]
    def parameterTypes(self, index):
        '''abstract list-of-QByteArray QDesignerMemberSheetExtension.parameterTypes(int index)'''
        return [QByteArray()]
    def signature(self, index):
        '''abstract str QDesignerMemberSheetExtension.signature(int index)'''
        return str()
    def declaredInClass(self, index):
        '''abstract str QDesignerMemberSheetExtension.declaredInClass(int index)'''
        return str()
    def inheritedFromWidget(self, index):
        '''abstract bool QDesignerMemberSheetExtension.inheritedFromWidget(int index)'''
        return bool()
    def isSlot(self, index):
        '''abstract bool QDesignerMemberSheetExtension.isSlot(int index)'''
        return bool()
    def isSignal(self, index):
        '''abstract bool QDesignerMemberSheetExtension.isSignal(int index)'''
        return bool()
    def setVisible(self, index, b):
        '''abstract void QDesignerMemberSheetExtension.setVisible(int index, bool b)'''
    def isVisible(self, index):
        '''abstract bool QDesignerMemberSheetExtension.isVisible(int index)'''
        return bool()
    def setMemberGroup(self, index, group):
        '''abstract void QDesignerMemberSheetExtension.setMemberGroup(int index, str group)'''
    def memberGroup(self, index):
        '''abstract str QDesignerMemberSheetExtension.memberGroup(int index)'''
        return str()
    def memberName(self, index):
        '''abstract str QDesignerMemberSheetExtension.memberName(int index)'''
        return str()
    def indexOf(self, name):
        '''abstract int QDesignerMemberSheetExtension.indexOf(str name)'''
        return int()
    def __len__(self):
        ''' QDesignerMemberSheetExtension.__len__()'''
        return ()
    def count(self):
        '''abstract int QDesignerMemberSheetExtension.count()'''
        return int()


class QDesignerPropertySheetExtension():
    """"""
    def __init__(self):
        '''void QDesignerPropertySheetExtension.__init__()'''
    def __init__(self):
        '''QDesignerPropertySheetExtension QDesignerPropertySheetExtension.__init__()'''
        return QDesignerPropertySheetExtension()
    def isEnabled(self, index):
        '''bool QDesignerPropertySheetExtension.isEnabled(int index)'''
        return bool()
    def setChanged(self, index, changed):
        '''abstract void QDesignerPropertySheetExtension.setChanged(int index, bool changed)'''
    def isChanged(self, index):
        '''abstract bool QDesignerPropertySheetExtension.isChanged(int index)'''
        return bool()
    def setProperty(self, index, value):
        '''abstract void QDesignerPropertySheetExtension.setProperty(int index, QVariant value)'''
    def property(self, index):
        '''abstract QVariant QDesignerPropertySheetExtension.property(int index)'''
        return QVariant()
    def setAttribute(self, index, b):
        '''abstract void QDesignerPropertySheetExtension.setAttribute(int index, bool b)'''
    def isAttribute(self, index):
        '''abstract bool QDesignerPropertySheetExtension.isAttribute(int index)'''
        return bool()
    def setVisible(self, index, b):
        '''abstract void QDesignerPropertySheetExtension.setVisible(int index, bool b)'''
    def isVisible(self, index):
        '''abstract bool QDesignerPropertySheetExtension.isVisible(int index)'''
        return bool()
    def reset(self, index):
        '''abstract bool QDesignerPropertySheetExtension.reset(int index)'''
        return bool()
    def hasReset(self, index):
        '''abstract bool QDesignerPropertySheetExtension.hasReset(int index)'''
        return bool()
    def setPropertyGroup(self, index, group):
        '''abstract void QDesignerPropertySheetExtension.setPropertyGroup(int index, str group)'''
    def propertyGroup(self, index):
        '''abstract str QDesignerPropertySheetExtension.propertyGroup(int index)'''
        return str()
    def propertyName(self, index):
        '''abstract str QDesignerPropertySheetExtension.propertyName(int index)'''
        return str()
    def indexOf(self, name):
        '''abstract int QDesignerPropertySheetExtension.indexOf(str name)'''
        return int()
    def __len__(self):
        ''' QDesignerPropertySheetExtension.__len__()'''
        return ()
    def count(self):
        '''abstract int QDesignerPropertySheetExtension.count()'''
        return int()


class QExtensionManager(QObject, QAbstractExtensionManager):
    """"""
    def __init__(self, parent = None):
        '''void QExtensionManager.__init__(QObject parent = None)'''
    def extension(self, object, iid):
        '''QObject QExtensionManager.extension(QObject object, str iid)'''
        return QObject()
    def unregisterExtensions(self, factory, iid = None):
        '''void QExtensionManager.unregisterExtensions(QAbstractExtensionFactory factory, str iid = '')'''
    def registerExtensions(self, factory, iid = None):
        '''void QExtensionManager.registerExtensions(QAbstractExtensionFactory factory, str iid = '')'''


class QDesignerTaskMenuExtension():
    """"""
    def __init__(self):
        '''void QDesignerTaskMenuExtension.__init__()'''
    def __init__(self):
        '''QDesignerTaskMenuExtension QDesignerTaskMenuExtension.__init__()'''
        return QDesignerTaskMenuExtension()
    def preferredEditAction(self):
        '''QAction QDesignerTaskMenuExtension.preferredEditAction()'''
        return QAction()
    def taskActions(self):
        '''abstract list-of-QAction QDesignerTaskMenuExtension.taskActions()'''
        return [QAction()]


class QPyDesignerContainerExtension(QObject, QDesignerContainerExtension):
    """"""
    def __init__(self, parent):
        '''void QPyDesignerContainerExtension.__init__(QObject parent)'''


class QPyDesignerCustomWidgetCollectionPlugin(QObject, QDesignerCustomWidgetCollectionInterface):
    """"""
    def __init__(self, parent = None):
        '''void QPyDesignerCustomWidgetCollectionPlugin.__init__(QObject parent = None)'''


class QPyDesignerCustomWidgetPlugin(QObject, QDesignerCustomWidgetInterface):
    """"""
    def __init__(self, parent = None):
        '''void QPyDesignerCustomWidgetPlugin.__init__(QObject parent = None)'''


class QPyDesignerMemberSheetExtension(QObject, QDesignerMemberSheetExtension):
    """"""
    def __init__(self, parent):
        '''void QPyDesignerMemberSheetExtension.__init__(QObject parent)'''


class QPyDesignerPropertySheetExtension(QObject, QDesignerPropertySheetExtension):
    """"""
    def __init__(self, parent):
        '''void QPyDesignerPropertySheetExtension.__init__(QObject parent)'''


class QPyDesignerTaskMenuExtension(QObject, QDesignerTaskMenuExtension):
    """"""
    def __init__(self, parent):
        '''void QPyDesignerTaskMenuExtension.__init__(QObject parent)'''





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class QAssistantClient(QObject):
    """"""
    def __init__(self, path, parent = None):
        '''void QAssistantClient.__init__(QString path, QObject parent = None)'''
    error = pyqtSignal() # void error(const QStringamp;) - signal
    assistantClosed = pyqtSignal() # void assistantClosed() - signal
    assistantOpened = pyqtSignal() # void assistantOpened() - signal
    def showPage(self, page):
        '''void QAssistantClient.showPage(QString page)'''
    def closeAssistant(self):
        '''void QAssistantClient.closeAssistant()'''
    def openAssistant(self):
        '''void QAssistantClient.openAssistant()'''
    def setArguments(self, arguments):
        '''void QAssistantClient.setArguments(QStringList arguments)'''
    def isOpen(self):
        '''bool QAssistantClient.isOpen()'''
        return bool()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class Solid():
    """"""
    # Enum Solid.ErrorType
    NoError = 0
    UnauthorizedOperation = 0
    DeviceBusy = 0
    OperationFailed = 0
    UserCanceled = 0
    InvalidOption = 0
    MissingDriver = 0

    class Processor(Solid.DeviceInterface):
        """"""
        # Enum Solid.Processor.InstructionSet
        NoExtensions = 0
        IntelMmx = 0
        IntelSse = 0
        IntelSse2 = 0
        IntelSse3 = 0
        IntelSse4 = 0
        Amd3DNow = 0
        AltiVec = 0
    
        def instructionSets(self):
            '''Solid.Processor.InstructionSets Solid.Processor.instructionSets()'''
            return Solid.Processor.InstructionSets()
        def canChangeFrequency(self):
            '''bool Solid.Processor.canChangeFrequency()'''
            return bool()
        def maxSpeed(self):
            '''int Solid.Processor.maxSpeed()'''
            return int()
        def number(self):
            '''int Solid.Processor.number()'''
            return int()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.Processor.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class StorageDrive(Solid.DeviceInterface):
        """"""
        # Enum Solid.StorageDrive.DriveType
        HardDisk = 0
        CdromDrive = 0
        Floppy = 0
        Tape = 0
        CompactFlash = 0
        MemoryStick = 0
        SmartMedia = 0
        SdMmc = 0
        Xd = 0
    
        # Enum Solid.StorageDrive.Bus
        Ide = 0
        Usb = 0
        Ieee1394 = 0
        Scsi = 0
        Sata = 0
        Platform = 0
    
        def isInUse(self):
            '''bool Solid.StorageDrive.isInUse()'''
            return bool()
        def size(self):
            '''int Solid.StorageDrive.size()'''
            return int()
        def isHotpluggable(self):
            '''bool Solid.StorageDrive.isHotpluggable()'''
            return bool()
        def isRemovable(self):
            '''bool Solid.StorageDrive.isRemovable()'''
            return bool()
        def driveType(self):
            '''Solid.StorageDrive.DriveType Solid.StorageDrive.driveType()'''
            return Solid.StorageDrive.DriveType()
        def bus(self):
            '''Solid.StorageDrive.Bus Solid.StorageDrive.bus()'''
            return Solid.StorageDrive.Bus()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.StorageDrive.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class Video(Solid.DeviceInterface):
        """"""
        def driverHandle(self, driver):
            '''QVariant Solid.Video.driverHandle(QString driver)'''
            return QVariant()
        def supportedDrivers(self, protocol = QString()):
            '''QStringList Solid.Video.supportedDrivers(QString protocol = QString())'''
            return QStringList()
        def supportedProtocols(self):
            '''QStringList Solid.Video.supportedProtocols()'''
            return QStringList()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.Video.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class OpticalDrive(Solid.StorageDrive):
        """"""
        # Enum Solid.OpticalDrive.MediumType
        Cdr = 0
        Cdrw = 0
        Dvd = 0
        Dvdr = 0
        Dvdrw = 0
        Dvdram = 0
        Dvdplusr = 0
        Dvdplusrw = 0
        Dvdplusdl = 0
        Dvdplusdlrw = 0
        Bd = 0
        Bdr = 0
        Bdre = 0
        HdDvd = 0
        HdDvdr = 0
        HdDvdrw = 0
    
        ejectRequested = pyqtSignal() # void ejectRequested(const QStringamp;) - signal
        ejectDone = pyqtSignal() # void ejectDone(Solid::ErrorType,QVariant,const QStringamp;) - signal
        ejectPressed = pyqtSignal() # void ejectPressed(const QStringamp;) - signal
        def eject(self):
            '''bool Solid.OpticalDrive.eject()'''
            return bool()
        def writeSpeeds(self):
            '''list-of-int Solid.OpticalDrive.writeSpeeds()'''
            return [int()]
        def writeSpeed(self):
            '''int Solid.OpticalDrive.writeSpeed()'''
            return int()
        def readSpeed(self):
            '''int Solid.OpticalDrive.readSpeed()'''
            return int()
        def supportedMedia(self):
            '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.supportedMedia()'''
            return Solid.OpticalDrive.MediumTypes()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.OpticalDrive.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class SmartCardReader(Solid.DeviceInterface):
        """"""
        # Enum Solid.SmartCardReader.ReaderType
        UnknownReaderType = 0
        CardReader = 0
        CryptoToken = 0
    
        def readerType(self):
            '''Solid.SmartCardReader.ReaderType Solid.SmartCardReader.readerType()'''
            return Solid.SmartCardReader.ReaderType()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.SmartCardReader.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class AcAdapter(Solid.DeviceInterface):
        """"""
        plugStateChanged = pyqtSignal() # void plugStateChanged(bool,const QStringamp;) - signal
        def isPlugged(self):
            '''bool Solid.AcAdapter.isPlugged()'''
            return bool()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.AcAdapter.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class NetworkShare(Solid.DeviceInterface):
        """"""
        # Enum Solid.NetworkShare.ShareType
        Unknown = 0
        Nfs = 0
        Cifs = 0
        Upnp = 0
    
        def url(self):
            '''QUrl Solid.NetworkShare.url()'''
            return QUrl()
        def type(self):
            '''Solid.NetworkShare.ShareType Solid.NetworkShare.type()'''
            return Solid.NetworkShare.ShareType()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.NetworkShare.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class StorageVolume(Solid.DeviceInterface):
        """"""
        # Enum Solid.StorageVolume.UsageType
        Other = 0
        Unused = 0
        FileSystem = 0
        PartitionTable = 0
        Raid = 0
        Encrypted = 0
    
        def encryptedContainer(self):
            '''Solid.Device Solid.StorageVolume.encryptedContainer()'''
            return Solid.Device()
        def size(self):
            '''int Solid.StorageVolume.size()'''
            return int()
        def uuid(self):
            '''QString Solid.StorageVolume.uuid()'''
            return QString()
        def label(self):
            '''QString Solid.StorageVolume.label()'''
            return QString()
        def fsType(self):
            '''QString Solid.StorageVolume.fsType()'''
            return QString()
        def usage(self):
            '''Solid.StorageVolume.UsageType Solid.StorageVolume.usage()'''
            return Solid.StorageVolume.UsageType()
        def isIgnored(self):
            '''bool Solid.StorageVolume.isIgnored()'''
            return bool()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.StorageVolume.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class OpticalDisc():
        """"""
        class ContentTypes():
            """"""
            def __init__(self):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__init__()'''
                return Solid.OpticalDisc.ContentTypes()
            def __init__(self):
                '''int Solid.OpticalDisc.ContentTypes.__init__()'''
                return int()
            def __init__(self):
                '''void Solid.OpticalDisc.ContentTypes.__init__()'''
            def __bool__(self):
                '''int Solid.OpticalDisc.ContentTypes.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool Solid.OpticalDisc.ContentTypes.__ne__(Solid.OpticalDisc.ContentTypes f)'''
                return bool()
            def __eq__(self, f):
                '''bool Solid.OpticalDisc.ContentTypes.__eq__(Solid.OpticalDisc.ContentTypes f)'''
                return bool()
            def __invert__(self):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__invert__()'''
                return Solid.OpticalDisc.ContentTypes()
            def __and__(self, mask):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__and__(int mask)'''
                return Solid.OpticalDisc.ContentTypes()
            def __xor__(self, f):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__xor__(Solid.OpticalDisc.ContentTypes f)'''
                return Solid.OpticalDisc.ContentTypes()
            def __xor__(self, f):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__xor__(int f)'''
                return Solid.OpticalDisc.ContentTypes()
            def __or__(self, f):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__or__(Solid.OpticalDisc.ContentTypes f)'''
                return Solid.OpticalDisc.ContentTypes()
            def __or__(self, f):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__or__(int f)'''
                return Solid.OpticalDisc.ContentTypes()
            def __int__(self):
                '''int Solid.OpticalDisc.ContentTypes.__int__()'''
                return int()
            def __ixor__(self, f):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__ixor__(Solid.OpticalDisc.ContentTypes f)'''
                return Solid.OpticalDisc.ContentTypes()
            def __ior__(self, f):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__ior__(Solid.OpticalDisc.ContentTypes f)'''
                return Solid.OpticalDisc.ContentTypes()
            def __iand__(self, mask):
                '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.ContentTypes.__iand__(int mask)'''
                return Solid.OpticalDisc.ContentTypes()
    class OpticalDisc(Solid.StorageVolume):
        """"""
        # Enum Solid.OpticalDisc.DiscType
        UnknownDiscType = 0
        CdRom = 0
        CdRecordable = 0
        CdRewritable = 0
        DvdRom = 0
        DvdRam = 0
        DvdRecordable = 0
        DvdRewritable = 0
        DvdPlusRecordable = 0
        DvdPlusRewritable = 0
        DvdPlusRecordableDuallayer = 0
        DvdPlusRewritableDuallayer = 0
        BluRayRom = 0
        BluRayRecordable = 0
        BluRayRewritable = 0
        HdDvdRom = 0
        HdDvdRecordable = 0
        HdDvdRewritable = 0
    
        # Enum Solid.OpticalDisc.ContentType
        NoContent = 0
        Audio = 0
        Data = 0
        VideoCd = 0
        SuperVideoCd = 0
        VideoDvd = 0
        VideoBluRay = 0
    
        def capacity(self):
            '''int Solid.OpticalDisc.capacity()'''
            return int()
        def isRewritable(self):
            '''bool Solid.OpticalDisc.isRewritable()'''
            return bool()
        def isBlank(self):
            '''bool Solid.OpticalDisc.isBlank()'''
            return bool()
        def isAppendable(self):
            '''bool Solid.OpticalDisc.isAppendable()'''
            return bool()
        def discType(self):
            '''Solid.OpticalDisc.DiscType Solid.OpticalDisc.discType()'''
            return Solid.OpticalDisc.DiscType()
        def availableContent(self):
            '''Solid.OpticalDisc.ContentTypes Solid.OpticalDisc.availableContent()'''
            return Solid.OpticalDisc.ContentTypes()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.OpticalDisc.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class Block(Solid.DeviceInterface):
        """"""
        def device(self):
            '''QString Solid.Block.device()'''
            return QString()
        def deviceMinor(self):
            '''int Solid.Block.deviceMinor()'''
            return int()
        def deviceMajor(self):
            '''int Solid.Block.deviceMajor()'''
            return int()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.Block.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class Networking():
        """"""
        class Notifier(QObject):
            """"""
            def __init__(self):
                '''void Solid.Networking.Notifier.__init__()'''
    class AudioInterface():
        """"""
        class AudioInterfaceTypes():
            """"""
            def __init__(self):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__init__()'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __init__(self):
                '''int Solid.AudioInterface.AudioInterfaceTypes.__init__()'''
                return int()
            def __init__(self):
                '''void Solid.AudioInterface.AudioInterfaceTypes.__init__()'''
            def __bool__(self):
                '''int Solid.AudioInterface.AudioInterfaceTypes.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool Solid.AudioInterface.AudioInterfaceTypes.__ne__(Solid.AudioInterface.AudioInterfaceTypes f)'''
                return bool()
            def __eq__(self, f):
                '''bool Solid.AudioInterface.AudioInterfaceTypes.__eq__(Solid.AudioInterface.AudioInterfaceTypes f)'''
                return bool()
            def __invert__(self):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__invert__()'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __and__(self, mask):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__and__(int mask)'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __xor__(self, f):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__xor__(Solid.AudioInterface.AudioInterfaceTypes f)'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __xor__(self, f):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__xor__(int f)'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __or__(self, f):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__or__(Solid.AudioInterface.AudioInterfaceTypes f)'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __or__(self, f):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__or__(int f)'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __int__(self):
                '''int Solid.AudioInterface.AudioInterfaceTypes.__int__()'''
                return int()
            def __ixor__(self, f):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__ixor__(Solid.AudioInterface.AudioInterfaceTypes f)'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __ior__(self, f):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__ior__(Solid.AudioInterface.AudioInterfaceTypes f)'''
                return Solid.AudioInterface.AudioInterfaceTypes()
            def __iand__(self, mask):
                '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.AudioInterfaceTypes.__iand__(int mask)'''
                return Solid.AudioInterface.AudioInterfaceTypes()
    class Battery(Solid.DeviceInterface):
        """"""
        # Enum Solid.Battery.ChargeState
        NoCharge = 0
        Charging = 0
        Discharging = 0
    
        # Enum Solid.Battery.BatteryType
        UnknownBattery = 0
        PdaBattery = 0
        UpsBattery = 0
        PrimaryBattery = 0
        MouseBattery = 0
        KeyboardBattery = 0
        KeyboardMouseBattery = 0
        CameraBattery = 0
        PhoneBattery = 0
        MonitorBattery = 0
    
        plugStateChanged = pyqtSignal() # void plugStateChanged(bool,const QStringamp;) - signal
        chargeStateChanged = pyqtSignal() # void chargeStateChanged(int,const QStringamp;) - signal
        chargePercentChanged = pyqtSignal() # void chargePercentChanged(int,const QStringamp;) - signal
        def chargeState(self):
            '''Solid.Battery.ChargeState Solid.Battery.chargeState()'''
            return Solid.Battery.ChargeState()
        def isRechargeable(self):
            '''bool Solid.Battery.isRechargeable()'''
            return bool()
        def chargePercent(self):
            '''int Solid.Battery.chargePercent()'''
            return int()
        def type(self):
            '''Solid.Battery.BatteryType Solid.Battery.type()'''
            return Solid.Battery.BatteryType()
        def isPlugged(self):
            '''bool Solid.Battery.isPlugged()'''
            return bool()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.Battery.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class Networking():
        """"""
        # Enum Solid.Networking.ManagementPolicy
        Manual = 0
        OnNextStatusChange = 0
        Managed = 0
    
        # Enum Solid.Networking.Status
        Unknown = 0
        Unconnected = 0
        Disconnecting = 0
        Connecting = 0
        Connected = 0
    
        def notifier(self):
            '''static Solid.Networking.Notifier Solid.Networking.notifier()'''
            return Solid.Networking.Notifier()
        def status(self):
            '''static Solid.Networking.Status Solid.Networking.status()'''
            return Solid.Networking.Status()
    class Camera(Solid.DeviceInterface):
        """"""
        def driverHandle(self, driver):
            '''QVariant Solid.Camera.driverHandle(QString driver)'''
            return QVariant()
        def supportedDrivers(self, protocol = QString()):
            '''QStringList Solid.Camera.supportedDrivers(QString protocol = QString())'''
            return QStringList()
        def supportedProtocols(self):
            '''QStringList Solid.Camera.supportedProtocols()'''
            return QStringList()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.Camera.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class InternetGateway(Solid.DeviceInterface):
        """"""
        # Enum Solid.InternetGateway.NetworkProtocol
        TCP = 0
        UDP = 0
    
        # Enum Solid.InternetGateway.InternetStatus
        InternetEnabled = 0
        InternetDisabled = 0
        UnknownStatus = 0
    
        currentConnectionsDataIsReady = pyqtSignal() # void currentConnectionsDataIsReady(QStringList) - signal
        enabledForInternet = pyqtSignal() # void enabledForInternet(bool) - signal
        portMappingDeleted = pyqtSignal() # void portMappingDeleted(const QStringamp;,qint16,const Solid::InternetGateway::NetworkProtocolamp;) - signal
        portMappingAdded = pyqtSignal() # void portMappingAdded(const QStringamp;,qint16,const Solid::InternetGateway::NetworkProtocolamp;,qint16,const QStringamp;) - signal
        def setEnabledForInternet(self, enabled):
            '''void Solid.InternetGateway.setEnabledForInternet(bool enabled)'''
        def isEnabledForInternet(self):
            '''Solid.InternetGateway.InternetStatus Solid.InternetGateway.isEnabledForInternet()'''
            return Solid.InternetGateway.InternetStatus()
        def deletePortMapping(self, remoteHost, externalPort, mappingProtocol):
            '''void Solid.InternetGateway.deletePortMapping(QString remoteHost, int externalPort, Solid.InternetGateway.NetworkProtocol mappingProtocol)'''
        def addPortMapping(self, remoteHost, externalPort, mappingProtocol, internalPort, internalClient):
            '''void Solid.InternetGateway.addPortMapping(QString remoteHost, int externalPort, Solid.InternetGateway.NetworkProtocol mappingProtocol, int internalPort, QString internalClient)'''
        def currentConnections(self):
            '''QStringList Solid.InternetGateway.currentConnections()'''
            return QStringList()
        def requestCurrentConnections(self):
            '''void Solid.InternetGateway.requestCurrentConnections()'''
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.InternetGateway.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class SerialInterface(Solid.DeviceInterface):
        """"""
        # Enum Solid.SerialInterface.SerialType
        Unknown = 0
        Platform = 0
        Usb = 0
    
        def port(self):
            '''int Solid.SerialInterface.port()'''
            return int()
        def serialType(self):
            '''Solid.SerialInterface.SerialType Solid.SerialInterface.serialType()'''
            return Solid.SerialInterface.SerialType()
        def driverHandle(self):
            '''QVariant Solid.SerialInterface.driverHandle()'''
            return QVariant()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.SerialInterface.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class OpticalDrive():
        """"""
        class MediumTypes():
            """"""
            def __init__(self):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__init__()'''
                return Solid.OpticalDrive.MediumTypes()
            def __init__(self):
                '''int Solid.OpticalDrive.MediumTypes.__init__()'''
                return int()
            def __init__(self):
                '''void Solid.OpticalDrive.MediumTypes.__init__()'''
            def __bool__(self):
                '''int Solid.OpticalDrive.MediumTypes.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool Solid.OpticalDrive.MediumTypes.__ne__(Solid.OpticalDrive.MediumTypes f)'''
                return bool()
            def __eq__(self, f):
                '''bool Solid.OpticalDrive.MediumTypes.__eq__(Solid.OpticalDrive.MediumTypes f)'''
                return bool()
            def __invert__(self):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__invert__()'''
                return Solid.OpticalDrive.MediumTypes()
            def __and__(self, mask):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__and__(int mask)'''
                return Solid.OpticalDrive.MediumTypes()
            def __xor__(self, f):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__xor__(Solid.OpticalDrive.MediumTypes f)'''
                return Solid.OpticalDrive.MediumTypes()
            def __xor__(self, f):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__xor__(int f)'''
                return Solid.OpticalDrive.MediumTypes()
            def __or__(self, f):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__or__(Solid.OpticalDrive.MediumTypes f)'''
                return Solid.OpticalDrive.MediumTypes()
            def __or__(self, f):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__or__(int f)'''
                return Solid.OpticalDrive.MediumTypes()
            def __int__(self):
                '''int Solid.OpticalDrive.MediumTypes.__int__()'''
                return int()
            def __ixor__(self, f):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__ixor__(Solid.OpticalDrive.MediumTypes f)'''
                return Solid.OpticalDrive.MediumTypes()
            def __ior__(self, f):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__ior__(Solid.OpticalDrive.MediumTypes f)'''
                return Solid.OpticalDrive.MediumTypes()
            def __iand__(self, mask):
                '''Solid.OpticalDrive.MediumTypes Solid.OpticalDrive.MediumTypes.__iand__(int mask)'''
                return Solid.OpticalDrive.MediumTypes()
    class Device():
        """"""
        def __init__(self, udi = QString()):
            '''void Solid.Device.__init__(QString udi = QString())'''
        def __init__(self, device):
            '''void Solid.Device.__init__(Solid.Device device)'''
        def description(self):
            '''QString Solid.Device.description()'''
            return QString()
        def emblems(self):
            '''QStringList Solid.Device.emblems()'''
            return QStringList()
        def asDeviceInterface(self, type):
            '''Solid.DeviceInterface Solid.Device.asDeviceInterface(Solid.DeviceInterface.Type type)'''
            return Solid.DeviceInterface()
        def isDeviceInterface(self, type):
            '''bool Solid.Device.isDeviceInterface(Solid.DeviceInterface.Type type)'''
            return bool()
        def icon(self):
            '''QString Solid.Device.icon()'''
            return QString()
        def product(self):
            '''QString Solid.Device.product()'''
            return QString()
        def vendor(self):
            '''QString Solid.Device.vendor()'''
            return QString()
        def parent(self):
            '''Solid.Device Solid.Device.parent()'''
            return Solid.Device()
        def parentUdi(self):
            '''QString Solid.Device.parentUdi()'''
            return QString()
        def udi(self):
            '''QString Solid.Device.udi()'''
            return QString()
        def isValid(self):
            '''bool Solid.Device.isValid()'''
            return bool()
        def listFromQuery(self, predicate, parentUdi = QString()):
            '''static list-of-Solid.Device Solid.Device.listFromQuery(Solid.Predicate predicate, QString parentUdi = QString())'''
            return [Solid.Device()]
        def listFromQuery(self, predicate, parentUdi = QString()):
            '''static list-of-Solid.Device Solid.Device.listFromQuery(QString predicate, QString parentUdi = QString())'''
            return [Solid.Device()]
        def listFromType(self, type, parentUdi = QString()):
            '''static list-of-Solid.Device Solid.Device.listFromType(Solid.DeviceInterface.Type type, QString parentUdi = QString())'''
            return [Solid.Device()]
        def allDevices(self):
            '''static list-of-Solid.Device Solid.Device.allDevices()'''
            return [Solid.Device()]
    class DvbInterface(Solid.DeviceInterface):
        """"""
        # Enum Solid.DvbInterface.DeviceType
        DvbUnknown = 0
        DvbAudio = 0
        DvbCa = 0
        DvbDemux = 0
        DvbDvr = 0
        DvbFrontend = 0
        DvbNet = 0
        DvbOsd = 0
        DvbSec = 0
        DvbVideo = 0
    
        def deviceIndex(self):
            '''int Solid.DvbInterface.deviceIndex()'''
            return int()
        def deviceType(self):
            '''Solid.DvbInterface.DeviceType Solid.DvbInterface.deviceType()'''
            return Solid.DvbInterface.DeviceType()
        def deviceAdapter(self):
            '''int Solid.DvbInterface.deviceAdapter()'''
            return int()
        def device(self):
            '''QString Solid.DvbInterface.device()'''
            return QString()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.DvbInterface.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class NetworkInterface(Solid.DeviceInterface):
        """"""
        def macAddress(self):
            '''int Solid.NetworkInterface.macAddress()'''
            return int()
        def hwAddress(self):
            '''QString Solid.NetworkInterface.hwAddress()'''
            return QString()
        def isWireless(self):
            '''bool Solid.NetworkInterface.isWireless()'''
            return bool()
        def ifaceName(self):
            '''QString Solid.NetworkInterface.ifaceName()'''
            return QString()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.NetworkInterface.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class DeviceNotifier(QObject):
        """"""
        def __init__(self):
            '''void Solid.DeviceNotifier.__init__()'''
        deviceRemoved = pyqtSignal() # void deviceRemoved(const QStringamp;) - signal
        deviceAdded = pyqtSignal() # void deviceAdded(const QStringamp;) - signal
        def instance(self):
            '''static Solid.DeviceNotifier Solid.DeviceNotifier.instance()'''
            return Solid.DeviceNotifier()
    class Processor():
        """"""
        class InstructionSets():
            """"""
            def __init__(self):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__init__()'''
                return Solid.Processor.InstructionSets()
            def __init__(self):
                '''int Solid.Processor.InstructionSets.__init__()'''
                return int()
            def __init__(self):
                '''void Solid.Processor.InstructionSets.__init__()'''
            def __bool__(self):
                '''int Solid.Processor.InstructionSets.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool Solid.Processor.InstructionSets.__ne__(Solid.Processor.InstructionSets f)'''
                return bool()
            def __eq__(self, f):
                '''bool Solid.Processor.InstructionSets.__eq__(Solid.Processor.InstructionSets f)'''
                return bool()
            def __invert__(self):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__invert__()'''
                return Solid.Processor.InstructionSets()
            def __and__(self, mask):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__and__(int mask)'''
                return Solid.Processor.InstructionSets()
            def __xor__(self, f):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__xor__(Solid.Processor.InstructionSets f)'''
                return Solid.Processor.InstructionSets()
            def __xor__(self, f):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__xor__(int f)'''
                return Solid.Processor.InstructionSets()
            def __or__(self, f):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__or__(Solid.Processor.InstructionSets f)'''
                return Solid.Processor.InstructionSets()
            def __or__(self, f):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__or__(int f)'''
                return Solid.Processor.InstructionSets()
            def __int__(self):
                '''int Solid.Processor.InstructionSets.__int__()'''
                return int()
            def __ixor__(self, f):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__ixor__(Solid.Processor.InstructionSets f)'''
                return Solid.Processor.InstructionSets()
            def __ior__(self, f):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__ior__(Solid.Processor.InstructionSets f)'''
                return Solid.Processor.InstructionSets()
            def __iand__(self, mask):
                '''Solid.Processor.InstructionSets Solid.Processor.InstructionSets.__iand__(int mask)'''
                return Solid.Processor.InstructionSets()
    class AudioInterface(Solid.DeviceInterface):
        """"""
        # Enum Solid.AudioInterface.SoundcardType
        InternalSoundcard = 0
        UsbSoundcard = 0
        FirewireSoundcard = 0
        Headset = 0
        Modem = 0
    
        # Enum Solid.AudioInterface.AudioInterfaceType
        UnknownAudioInterfaceType = 0
        AudioControl = 0
        AudioInput = 0
        AudioOutput = 0
    
        # Enum Solid.AudioInterface.AudioDriver
        Alsa = 0
        OpenSoundSystem = 0
        UnknownAudioDriver = 0
    
        def soundcardType(self):
            '''Solid.AudioInterface.SoundcardType Solid.AudioInterface.soundcardType()'''
            return Solid.AudioInterface.SoundcardType()
        def deviceType(self):
            '''Solid.AudioInterface.AudioInterfaceTypes Solid.AudioInterface.deviceType()'''
            return Solid.AudioInterface.AudioInterfaceTypes()
        def name(self):
            '''QString Solid.AudioInterface.name()'''
            return QString()
        def driverHandle(self):
            '''QVariant Solid.AudioInterface.driverHandle()'''
            return QVariant()
        def driver(self):
            '''Solid.AudioInterface.AudioDriver Solid.AudioInterface.driver()'''
            return Solid.AudioInterface.AudioDriver()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.AudioInterface.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class PowerManagement():
        """"""
        # Enum Solid.PowerManagement.SleepState
        StandbyState = 0
        SuspendState = 0
        HibernateState = 0
    
        def stopSuppressingScreenPowerManagement(self, cookie):
            '''static bool Solid.PowerManagement.stopSuppressingScreenPowerManagement(int cookie)'''
            return bool()
        def beginSuppressingScreenPowerManagement(self, reason = QString()):
            '''static int Solid.PowerManagement.beginSuppressingScreenPowerManagement(QString reason = QString())'''
            return int()
        def stopSuppressingSleep(self, cookie):
            '''static bool Solid.PowerManagement.stopSuppressingSleep(int cookie)'''
            return bool()
        def beginSuppressingSleep(self, reason = QString()):
            '''static int Solid.PowerManagement.beginSuppressingSleep(QString reason = QString())'''
            return int()
        def requestSleep(self, state, receiver, member):
            '''static void Solid.PowerManagement.requestSleep(Solid.PowerManagement.SleepState state, QObject receiver, str member)'''
        def supportedSleepStates(self):
            '''static unknown-type Solid.PowerManagement.supportedSleepStates()'''
            return unknown-type()
        def appShouldConserveResources(self):
            '''static bool Solid.PowerManagement.appShouldConserveResources()'''
            return bool()
    class StorageAccess(Solid.DeviceInterface):
        """"""
        def isIgnored(self):
            '''bool Solid.StorageAccess.isIgnored()'''
            return bool()
        teardownRequested = pyqtSignal() # void teardownRequested(const QStringamp;) - signal
        setupRequested = pyqtSignal() # void setupRequested(const QStringamp;) - signal
        teardownDone = pyqtSignal() # void teardownDone(Solid::ErrorType,QVariant,const QStringamp;) - signal
        setupDone = pyqtSignal() # void setupDone(Solid::ErrorType,QVariant,const QStringamp;) - signal
        accessibilityChanged = pyqtSignal() # void accessibilityChanged(bool,const QStringamp;) - signal
        def teardown(self):
            '''bool Solid.StorageAccess.teardown()'''
            return bool()
        def setup(self):
            '''bool Solid.StorageAccess.setup()'''
            return bool()
        def filePath(self):
            '''QString Solid.StorageAccess.filePath()'''
            return QString()
        def isAccessible(self):
            '''bool Solid.StorageAccess.isAccessible()'''
            return bool()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.StorageAccess.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class DeviceInterface(QObject):
        """"""
        # Enum Solid.DeviceInterface.Type
        Unknown = 0
        GenericInterface = 0
        Processor = 0
        Block = 0
        StorageAccess = 0
        StorageDrive = 0
        OpticalDrive = 0
        StorageVolume = 0
        OpticalDisc = 0
        Camera = 0
        PortableMediaPlayer = 0
        NetworkInterface = 0
        AcAdapter = 0
        Battery = 0
        Button = 0
        AudioInterface = 0
        DvbInterface = 0
        Video = 0
        SerialInterface = 0
        SmartCardReader = 0
        InternetGateway = 0
        NetworkShare = 0
        Last = 0
    
        def typeDescription(self, type):
            '''static QString Solid.DeviceInterface.typeDescription(Solid.DeviceInterface.Type type)'''
            return QString()
        def stringToType(self, type):
            '''static Solid.DeviceInterface.Type Solid.DeviceInterface.stringToType(QString type)'''
            return Solid.DeviceInterface.Type()
        def typeToString(self, type):
            '''static QString Solid.DeviceInterface.typeToString(Solid.DeviceInterface.Type type)'''
            return QString()
        def isValid(self):
            '''bool Solid.DeviceInterface.isValid()'''
            return bool()
    class Predicate():
        """"""
        # Enum Solid.Predicate.Type
        PropertyCheck = 0
        Conjunction = 0
        Disjunction = 0
        InterfaceCheck = 0
    
        # Enum Solid.Predicate.ComparisonOperator
        Equals = 0
        Mask = 0
    
        def __init__(self):
            '''void Solid.Predicate.__init__()'''
        def __init__(self, other):
            '''void Solid.Predicate.__init__(Solid.Predicate other)'''
        def __init__(self, ifaceName, property, value, compOperator = None):
            '''void Solid.Predicate.__init__(QString ifaceName, QString property, QVariant value, Solid.Predicate.ComparisonOperator compOperator = Solid.Predicate.Equals)'''
        def __init__(self, ifaceType):
            '''void Solid.Predicate.__init__(Solid.DeviceInterface.Type ifaceType)'''
        def __init__(self, ifaceName):
            '''void Solid.Predicate.__init__(QString ifaceName)'''
        def secondOperand(self):
            '''Solid.Predicate Solid.Predicate.secondOperand()'''
            return Solid.Predicate()
        def firstOperand(self):
            '''Solid.Predicate Solid.Predicate.firstOperand()'''
            return Solid.Predicate()
        def comparisonOperator(self):
            '''Solid.Predicate.ComparisonOperator Solid.Predicate.comparisonOperator()'''
            return Solid.Predicate.ComparisonOperator()
        def matchingValue(self):
            '''QVariant Solid.Predicate.matchingValue()'''
            return QVariant()
        def propertyName(self):
            '''QString Solid.Predicate.propertyName()'''
            return QString()
        def interfaceType(self):
            '''Solid.DeviceInterface.Type Solid.Predicate.interfaceType()'''
            return Solid.DeviceInterface.Type()
        def type(self):
            '''Solid.Predicate.Type Solid.Predicate.type()'''
            return Solid.Predicate.Type()
        def fromString(self, predicate):
            '''static Solid.Predicate Solid.Predicate.fromString(QString predicate)'''
            return Solid.Predicate()
        def toString(self):
            '''QString Solid.Predicate.toString()'''
            return QString()
        def usedTypes(self):
            '''unknown-type Solid.Predicate.usedTypes()'''
            return unknown-type()
        def matches(self, device):
            '''bool Solid.Predicate.matches(Solid.Device device)'''
            return bool()
        def isValid(self):
            '''bool Solid.Predicate.isValid()'''
            return bool()
        def __ior__(self, other):
            '''Solid.Predicate Solid.Predicate.__ior__(Solid.Predicate other)'''
            return Solid.Predicate()
        def __or__(self, other):
            '''Solid.Predicate Solid.Predicate.__or__(Solid.Predicate other)'''
            return Solid.Predicate()
        def __iand__(self, other):
            '''Solid.Predicate Solid.Predicate.__iand__(Solid.Predicate other)'''
            return Solid.Predicate()
        def __and__(self, other):
            '''Solid.Predicate Solid.Predicate.__and__(Solid.Predicate other)'''
            return Solid.Predicate()
    class GenericInterface(Solid.DeviceInterface):
        """"""
        # Enum Solid.GenericInterface.PropertyChange
        PropertyModified = 0
        PropertyAdded = 0
        PropertyRemoved = 0
    
        conditionRaised = pyqtSignal() # void conditionRaised(const QStringamp;,const QStringamp;) - signal
        def propertyExists(self, key):
            '''bool Solid.GenericInterface.propertyExists(QString key)'''
            return bool()
        def allProperties(self):
            '''dict-of-QString-QVariant Solid.GenericInterface.allProperties()'''
            return dict-of-QString-QVariant()
        def property(self, key):
            '''QVariant Solid.GenericInterface.property(QString key)'''
            return QVariant()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.GenericInterface.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class Button(Solid.DeviceInterface):
        """"""
        # Enum Solid.Button.ButtonType
        LidButton = 0
        PowerButton = 0
        SleepButton = 0
        UnknownButtonType = 0
        TabletButton = 0
    
        pressed = pyqtSignal() # void pressed(Solid::Button::ButtonType,const QStringamp;) - signal
        def stateValue(self):
            '''bool Solid.Button.stateValue()'''
            return bool()
        def hasState(self):
            '''bool Solid.Button.hasState()'''
            return bool()
        def type(self):
            '''Solid.Button.ButtonType Solid.Button.type()'''
            return Solid.Button.ButtonType()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.Button.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()
    class PortableMediaPlayer(Solid.DeviceInterface):
        """"""
        def driverHandle(self, driver):
            '''QVariant Solid.PortableMediaPlayer.driverHandle(QString driver)'''
            return QVariant()
        def supportedDrivers(self, protocol = QString()):
            '''QStringList Solid.PortableMediaPlayer.supportedDrivers(QString protocol = QString())'''
            return QStringList()
        def supportedProtocols(self):
            '''QStringList Solid.PortableMediaPlayer.supportedProtocols()'''
            return QStringList()
        def deviceInterfaceType(self):
            '''static Solid.DeviceInterface.Type Solid.PortableMediaPlayer.deviceInterfaceType()'''
            return Solid.DeviceInterface.Type()





# AUTO-GENERATED FILE -- DO NOT EDIT

""" A simple fast partial StringIO replacement.

This module provides a simple useful replacement for
the StringIO module that is written in C.  It does not provide the
full generality of StringIO, but it provides enough for most
applications and is especially useful in conjunction with the
pickle module.

Usage:

  from cStringIO import StringIO

  an_output_stream=StringIO()
  an_output_stream.write(some_stuff)
  ...
  value=an_output_stream.getvalue()

  an_input_stream=StringIO(a_string)
  spam=an_input_stream.readline()
  spam=an_input_stream.read(5)
  an_input_stream.seek(0)           # OK, start over
  spam=an_input_stream.read()       # and read it all
  
If someone else wants to provide a more complete implementation,
go for it. :-)  

cStringIO.c,v 1.29 1999/06/15 14:10:27 jim Exp
 """

class InputType(object):
  """ Simple type for treating strings as input file streams """

  def close(self):
    """ close(): explicitly release resources held. """
    pass

  closed = property(None, None, None,
                    """ True if the file is closed """
                    )


  def flush(self):
    """ flush(): does nothing. """
    pass

  def getvalue(self, use_pos=None):
    """ getvalue([use_pos]) -- Get the string value.
    If use_pos is specified and is a true value, then the string returned
    will include only the text up to the current file position.
     """
    return ""

  def isatty(self):
    """ isatty(): always returns 0 """
    pass

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

  def read(self, s=None):
    """ read([s]) -- Read s characters, or the rest of the string """
    return ""

  def readline(self):
    """ readline() -- Read one line """
    return None

  def readlines(self):
    """ readlines() -- Read all lines """
    return None

  def reset(self):
    """ reset() -- Reset the file position to the beginning """
    return file(__file__)

  def seek(self, position):
    """ seek(position)       -- set the current position
    seek(position, mode) -- mode 0: absolute; 1: relative; 2: relative to EOF """
    return None

  def tell(self):
    """ tell() -- get the current position. """
    return None

  def truncate(self):
    """ truncate(): truncate the file at the current position. """
    pass

class OutputType(object):
  """ Simple type for output to strings. """

  def close(self):
    """ close(): explicitly release resources held. """
    pass

  closed = property(None, None, None,
                    """ True if the file is closed """
                    )


  def flush(self):
    """ flush(): does nothing. """
    pass

  def getvalue(self, use_pos=None):
    """ getvalue([use_pos]) -- Get the string value.
    If use_pos is specified and is a true value, then the string returned
    will include only the text up to the current file position.
     """
    return ""

  def isatty(self):
    """ isatty(): always returns 0 """
    pass

  def next(self):
    """ x.next() -> the next value, or raise StopIteration """
    return None

  def read(self, s=None):
    """ read([s]) -- Read s characters, or the rest of the string """
    return ""

  def readline(self):
    """ readline() -- Read one line """
    return None

  def readlines(self):
    """ readlines() -- Read all lines """
    return None

  def reset(self):
    """ reset() -- Reset the file position to the beginning """
    return file(__file__)

  def seek(self, position):
    """ seek(position)       -- set the current position
    seek(position, mode) -- mode 0: absolute; 1: relative; 2: relative to EOF """
    return None

  softspace = None

  def tell(self):
    """ tell() -- get the current position. """
    return None

  def truncate(self):
    """ truncate(): truncate the file at the current position. """
    pass

  def write(self, s):
    """ write(s) -- Write a string to the file
    
    Note (hack:) writing None resets the buffer """
    return ""

  def writelines(self, sequence_of_strings):
    """ writelines(sequence_of_strings) -> None.  Write the strings to the file.
    
    Note that newlines are not added.  The sequence can be any iterable object
    producing strings. This is equivalent to calling write() for each string. """
    return ""

def StringIO(s=None):
  """ StringIO([s]) -- Return a StringIO-like stream for reading or writing """
  return ""

__package__ = None
cStringIO_CAPI = None




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QSerialPort(QIODevice):
    """"""
    # Enum QSerialPort.SerialPortError
    NoError = 0
    DeviceNotFoundError = 0
    PermissionError = 0
    OpenError = 0
    ParityError = 0
    FramingError = 0
    BreakConditionError = 0
    WriteError = 0
    ReadError = 0
    ResourceError = 0
    UnsupportedOperationError = 0
    TimeoutError = 0
    NotOpenError = 0
    UnknownError = 0

    # Enum QSerialPort.DataErrorPolicy
    SkipPolicy = 0
    PassZeroPolicy = 0
    IgnorePolicy = 0
    StopReceivingPolicy = 0
    UnknownPolicy = 0

    # Enum QSerialPort.PinoutSignal
    NoSignal = 0
    TransmittedDataSignal = 0
    ReceivedDataSignal = 0
    DataTerminalReadySignal = 0
    DataCarrierDetectSignal = 0
    DataSetReadySignal = 0
    RingIndicatorSignal = 0
    RequestToSendSignal = 0
    ClearToSendSignal = 0
    SecondaryTransmittedDataSignal = 0
    SecondaryReceivedDataSignal = 0

    # Enum QSerialPort.FlowControl
    NoFlowControl = 0
    HardwareControl = 0
    SoftwareControl = 0
    UnknownFlowControl = 0

    # Enum QSerialPort.StopBits
    OneStop = 0
    OneAndHalfStop = 0
    TwoStop = 0
    UnknownStopBits = 0

    # Enum QSerialPort.Parity
    NoParity = 0
    EvenParity = 0
    OddParity = 0
    SpaceParity = 0
    MarkParity = 0
    UnknownParity = 0

    # Enum QSerialPort.DataBits
    Data5 = 0
    Data6 = 0
    Data7 = 0
    Data8 = 0
    UnknownDataBits = 0

    # Enum QSerialPort.BaudRate
    Baud1200 = 0
    Baud2400 = 0
    Baud4800 = 0
    Baud9600 = 0
    Baud19200 = 0
    Baud38400 = 0
    Baud57600 = 0
    Baud115200 = 0
    UnknownBaud = 0

    # Enum QSerialPort.Direction
    Input = 0
    Output = 0
    AllDirections = 0

    def __init__(self, parent = None):
        '''void QSerialPort.__init__(QObject parent = None)'''
    def __init__(self, name, parent = None):
        '''void QSerialPort.__init__(str name, QObject parent = None)'''
    def __init__(self, info, parent = None):
        '''void QSerialPort.__init__(QSerialPortInfo info, QObject parent = None)'''
    breakEnabledChanged = pyqtSignal() # void breakEnabledChanged(bool) - signal
    def isBreakEnabled(self):
        '''bool QSerialPort.isBreakEnabled()'''
        return bool()
    def handle(self):
        '''int QSerialPort.handle()'''
        return int()
    def writeData(self, data):
        '''int QSerialPort.writeData(str data)'''
        return int()
    def readLineData(self, maxlen):
        '''str QSerialPort.readLineData(int maxlen)'''
        return str()
    def readData(self, maxlen):
        '''str QSerialPort.readData(int maxlen)'''
        return str()
    settingsRestoredOnCloseChanged = pyqtSignal() # void settingsRestoredOnCloseChanged(bool) - signal
    requestToSendChanged = pyqtSignal() # void requestToSendChanged(bool) - signal
    dataTerminalReadyChanged = pyqtSignal() # void dataTerminalReadyChanged(bool) - signal
    dataErrorPolicyChanged = pyqtSignal() # void dataErrorPolicyChanged(QSerialPort::DataErrorPolicy) - signal
    flowControlChanged = pyqtSignal() # void flowControlChanged(QSerialPort::FlowControl) - signal
    stopBitsChanged = pyqtSignal() # void stopBitsChanged(QSerialPort::StopBits) - signal
    parityChanged = pyqtSignal() # void parityChanged(QSerialPort::Parity) - signal
    dataBitsChanged = pyqtSignal() # void dataBitsChanged(QSerialPort::DataBits) - signal
    baudRateChanged = pyqtSignal() # void baudRateChanged(qint32,QSerialPort::Directions) - signal
    def setBreakEnabled(self, enabled = True):
        '''bool QSerialPort.setBreakEnabled(bool enabled = True)'''
        return bool()
    def sendBreak(self, duration = 0):
        '''bool QSerialPort.sendBreak(int duration = 0)'''
        return bool()
    def waitForBytesWritten(self, msecs):
        '''bool QSerialPort.waitForBytesWritten(int msecs)'''
        return bool()
    def waitForReadyRead(self, msecs):
        '''bool QSerialPort.waitForReadyRead(int msecs)'''
        return bool()
    def canReadLine(self):
        '''bool QSerialPort.canReadLine()'''
        return bool()
    def bytesToWrite(self):
        '''int QSerialPort.bytesToWrite()'''
        return int()
    def bytesAvailable(self):
        '''int QSerialPort.bytesAvailable()'''
        return int()
    def isSequential(self):
        '''bool QSerialPort.isSequential()'''
        return bool()
    def setReadBufferSize(self, size):
        '''void QSerialPort.setReadBufferSize(int size)'''
    def readBufferSize(self):
        '''int QSerialPort.readBufferSize()'''
        return int()
    def clearError(self):
        '''void QSerialPort.clearError()'''
    def error(self):
        '''QSerialPort.SerialPortError QSerialPort.error()'''
        return QSerialPort.SerialPortError()
    error = pyqtSignal() # void error(QSerialPort::SerialPortError) - signal
    def dataErrorPolicy(self):
        '''QSerialPort.DataErrorPolicy QSerialPort.dataErrorPolicy()'''
        return QSerialPort.DataErrorPolicy()
    def setDataErrorPolicy(self, policy = None):
        '''bool QSerialPort.setDataErrorPolicy(QSerialPort.DataErrorPolicy policy = QSerialPort.IgnorePolicy)'''
        return bool()
    def atEnd(self):
        '''bool QSerialPort.atEnd()'''
        return bool()
    def clear(self, dir = None):
        '''bool QSerialPort.clear(QSerialPort.Directions dir = QSerialPort.AllDirections)'''
        return bool()
    def flush(self):
        '''bool QSerialPort.flush()'''
        return bool()
    def pinoutSignals(self):
        '''QSerialPort.PinoutSignals QSerialPort.pinoutSignals()'''
        return QSerialPort.PinoutSignals()
    def isRequestToSend(self):
        '''bool QSerialPort.isRequestToSend()'''
        return bool()
    def setRequestToSend(self, set):
        '''bool QSerialPort.setRequestToSend(bool set)'''
        return bool()
    def isDataTerminalReady(self):
        '''bool QSerialPort.isDataTerminalReady()'''
        return bool()
    def setDataTerminalReady(self, set):
        '''bool QSerialPort.setDataTerminalReady(bool set)'''
        return bool()
    def flowControl(self):
        '''QSerialPort.FlowControl QSerialPort.flowControl()'''
        return QSerialPort.FlowControl()
    def setFlowControl(self, flow):
        '''bool QSerialPort.setFlowControl(QSerialPort.FlowControl flow)'''
        return bool()
    def stopBits(self):
        '''QSerialPort.StopBits QSerialPort.stopBits()'''
        return QSerialPort.StopBits()
    def setStopBits(self, stopBits):
        '''bool QSerialPort.setStopBits(QSerialPort.StopBits stopBits)'''
        return bool()
    def parity(self):
        '''QSerialPort.Parity QSerialPort.parity()'''
        return QSerialPort.Parity()
    def setParity(self, parity):
        '''bool QSerialPort.setParity(QSerialPort.Parity parity)'''
        return bool()
    def dataBits(self):
        '''QSerialPort.DataBits QSerialPort.dataBits()'''
        return QSerialPort.DataBits()
    def setDataBits(self, dataBits):
        '''bool QSerialPort.setDataBits(QSerialPort.DataBits dataBits)'''
        return bool()
    def baudRate(self, dir = None):
        '''int QSerialPort.baudRate(QSerialPort.Directions dir = QSerialPort.AllDirections)'''
        return int()
    def setBaudRate(self, baudRate, dir = None):
        '''bool QSerialPort.setBaudRate(int baudRate, QSerialPort.Directions dir = QSerialPort.AllDirections)'''
        return bool()
    def settingsRestoredOnClose(self):
        '''bool QSerialPort.settingsRestoredOnClose()'''
        return bool()
    def setSettingsRestoredOnClose(self, restore):
        '''void QSerialPort.setSettingsRestoredOnClose(bool restore)'''
    def close(self):
        '''void QSerialPort.close()'''
    def open(self, mode):
        '''bool QSerialPort.open(QIODevice.OpenMode mode)'''
        return bool()
    def setPort(self, info):
        '''void QSerialPort.setPort(QSerialPortInfo info)'''
    def portName(self):
        '''str QSerialPort.portName()'''
        return str()
    def setPortName(self, name):
        '''void QSerialPort.setPortName(str name)'''
    class PinoutSignals():
        """"""
        def __init__(self):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__init__()'''
            return QSerialPort.PinoutSignals()
        def __init__(self):
            '''int QSerialPort.PinoutSignals.__init__()'''
            return int()
        def __init__(self):
            '''void QSerialPort.PinoutSignals.__init__()'''
        def __bool__(self):
            '''int QSerialPort.PinoutSignals.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QSerialPort.PinoutSignals.__ne__(QSerialPort.PinoutSignals f)'''
            return bool()
        def __eq__(self, f):
            '''bool QSerialPort.PinoutSignals.__eq__(QSerialPort.PinoutSignals f)'''
            return bool()
        def __invert__(self):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__invert__()'''
            return QSerialPort.PinoutSignals()
        def __and__(self, mask):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__and__(int mask)'''
            return QSerialPort.PinoutSignals()
        def __xor__(self, f):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__xor__(QSerialPort.PinoutSignals f)'''
            return QSerialPort.PinoutSignals()
        def __xor__(self, f):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__xor__(int f)'''
            return QSerialPort.PinoutSignals()
        def __or__(self, f):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__or__(QSerialPort.PinoutSignals f)'''
            return QSerialPort.PinoutSignals()
        def __or__(self, f):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__or__(int f)'''
            return QSerialPort.PinoutSignals()
        def __int__(self):
            '''int QSerialPort.PinoutSignals.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__ixor__(QSerialPort.PinoutSignals f)'''
            return QSerialPort.PinoutSignals()
        def __ior__(self, f):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__ior__(QSerialPort.PinoutSignals f)'''
            return QSerialPort.PinoutSignals()
        def __iand__(self, mask):
            '''QSerialPort.PinoutSignals QSerialPort.PinoutSignals.__iand__(int mask)'''
            return QSerialPort.PinoutSignals()
    class Directions():
        """"""
        def __init__(self):
            '''QSerialPort.Directions QSerialPort.Directions.__init__()'''
            return QSerialPort.Directions()
        def __init__(self):
            '''int QSerialPort.Directions.__init__()'''
            return int()
        def __init__(self):
            '''void QSerialPort.Directions.__init__()'''
        def __bool__(self):
            '''int QSerialPort.Directions.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QSerialPort.Directions.__ne__(QSerialPort.Directions f)'''
            return bool()
        def __eq__(self, f):
            '''bool QSerialPort.Directions.__eq__(QSerialPort.Directions f)'''
            return bool()
        def __invert__(self):
            '''QSerialPort.Directions QSerialPort.Directions.__invert__()'''
            return QSerialPort.Directions()
        def __and__(self, mask):
            '''QSerialPort.Directions QSerialPort.Directions.__and__(int mask)'''
            return QSerialPort.Directions()
        def __xor__(self, f):
            '''QSerialPort.Directions QSerialPort.Directions.__xor__(QSerialPort.Directions f)'''
            return QSerialPort.Directions()
        def __xor__(self, f):
            '''QSerialPort.Directions QSerialPort.Directions.__xor__(int f)'''
            return QSerialPort.Directions()
        def __or__(self, f):
            '''QSerialPort.Directions QSerialPort.Directions.__or__(QSerialPort.Directions f)'''
            return QSerialPort.Directions()
        def __or__(self, f):
            '''QSerialPort.Directions QSerialPort.Directions.__or__(int f)'''
            return QSerialPort.Directions()
        def __int__(self):
            '''int QSerialPort.Directions.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QSerialPort.Directions QSerialPort.Directions.__ixor__(QSerialPort.Directions f)'''
            return QSerialPort.Directions()
        def __ior__(self, f):
            '''QSerialPort.Directions QSerialPort.Directions.__ior__(QSerialPort.Directions f)'''
            return QSerialPort.Directions()
        def __iand__(self, mask):
            '''QSerialPort.Directions QSerialPort.Directions.__iand__(int mask)'''
            return QSerialPort.Directions()


class QSerialPortInfo():
    """"""
    def __init__(self):
        '''void QSerialPortInfo.__init__()'''
    def __init__(self, port):
        '''void QSerialPortInfo.__init__(QSerialPort port)'''
    def __init__(self, name):
        '''void QSerialPortInfo.__init__(str name)'''
    def __init__(self, other):
        '''void QSerialPortInfo.__init__(QSerialPortInfo other)'''
    def serialNumber(self):
        '''str QSerialPortInfo.serialNumber()'''
        return str()
    def isNull(self):
        '''bool QSerialPortInfo.isNull()'''
        return bool()
    def availablePorts(self):
        '''static list-of-QSerialPortInfo QSerialPortInfo.availablePorts()'''
        return [QSerialPortInfo()]
    def standardBaudRates(self):
        '''static list-of-int QSerialPortInfo.standardBaudRates()'''
        return [int()]
    def isValid(self):
        '''bool QSerialPortInfo.isValid()'''
        return bool()
    def isBusy(self):
        '''bool QSerialPortInfo.isBusy()'''
        return bool()
    def hasProductIdentifier(self):
        '''bool QSerialPortInfo.hasProductIdentifier()'''
        return bool()
    def hasVendorIdentifier(self):
        '''bool QSerialPortInfo.hasVendorIdentifier()'''
        return bool()
    def productIdentifier(self):
        '''int QSerialPortInfo.productIdentifier()'''
        return int()
    def vendorIdentifier(self):
        '''int QSerialPortInfo.vendorIdentifier()'''
        return int()
    def manufacturer(self):
        '''str QSerialPortInfo.manufacturer()'''
        return str()
    def description(self):
        '''str QSerialPortInfo.description()'''
        return str()
    def systemLocation(self):
        '''str QSerialPortInfo.systemLocation()'''
        return str()
    def portName(self):
        '''str QSerialPortInfo.portName()'''
        return str()
    def swap(self, other):
        '''void QSerialPortInfo.swap(QSerialPortInfo other)'''





#!/usr/bin/env python2.7
# This file is part of KDevelop
# Copyright 2011 by Victor Varvariuc <victor.varvariuc@gmail.com>

from xml.dom import minidom


def indentCode(code, level):
    return '\n'.join('    ' * level + line for line in code.splitlines())


def parseEnum(enumNode, enumName, className = ''):
    '''Parse Enum node and return its string representation.'''
    enumMembers = []
    for node in enumNode.childNodes:
        if node.nodeType == node.ELEMENT_NODE:
            if node.nodeName == 'EnumMember':
                enumMember = node.attributes['name'].value
                if enumMember.startswith(className + '.'):
                    enumMember = enumMember[len(className) + 1:]
                if enumMember == 'None':
                    enumMember = '__kdevpythondocumentation_builtin_None'
                enumMembers.append(enumMember)
            else:
                print('Unknown node in Enum %s.%s: %s' % (className, enumName, node.nodeName))
    text = ''
    for enumMember in enumMembers:
        text += '%s = int() # %s.%s enum\n' % (enumMember, className, enumName)
    return text


def parseFunction(functionNode, funcName, className = ''):
    '''Parse Function node and return its string representation.'''
    params = [] if className == '' else [("None", "self")]
    retType = 'None'
    namesUsed = []
    for node in functionNode.childNodes:
        if node.nodeType == node.ELEMENT_NODE:
            if node.nodeName == 'Argument':
                argType = node.attributes['typename'].value
                try:
                    argName = '*args' if argType == '...' else '_' + node.attributes['name'].value
                except KeyError:
                    retType = argType
                else:
                    if argName not in namesUsed:
                        params.append((argType, argName))
                    else:
                        print("adjusting arg name:", argName)
                        argName = argName + '_'
                        params.append((argType, argName))
                    namesUsed.append(argName)
            else:
                print('Unknown node in function %s.%s: %s' % (className, funcName, node.nodeName))

    descr = 'abstract ' if 'abstract' in functionNode.attributes.keys() else ''
    descr += '%s %s.%s(%s)' % (retType, className, funcName,
                ', '.join('%s %s' % p for p in params))

    print("ret type:", retType)
    if retType == 'None':
        pass # leave it like this
    elif retType.startswith('list-of-'):
        retType = '[' + retType[8:] + '()]'
    elif retType.contains("-or-"):
        a, b = retType.split("-or-")
        retType = "{0}() if True else {1}()".format(a, b)
    elif retType.startsWith("dict-of-"):
        key, value = retType[8:].split('-')
        retType = '{' + key + "():" + value + "()}"
    else:
        retType += '()'

    # prefix function arguments with '_' to deal with reserved Python keywords
    text = 'def %s(%s):\n    """%s"""\n    return %s' % (funcName, ', '.join(param[1] for param in params), descr, retType)
    return text


def parseClass(classNode):
    '''Parse Class node.'''
    try:
        parentClasses = classNode.attributes['inherits'].value.split()
    except KeyError:
        parentClasses = []
    className = classNode.attributes['name'].value
    text = 'class %s(%s):\n    """"""\n' % (className, ', '.join(parentClasses))
    for node in classNode.childNodes:
        if node.nodeType == node.ELEMENT_NODE:
            name = node.attributes['name'].value
            if name.startswith(className + '.'):
                name = name[len(className) + 1 :]
            if node.nodeName == 'Member':
                text += '    %s = None # %s member\n' % (name, node.attributes['typename'].value)
            elif node.nodeName == 'Function':
                if name not in ('exec', 'print'): # skip this invalid for Python name
                    text += indentCode(parseFunction(node, name, className), 1) + '\n'
            elif node.nodeName == 'Enum':
                text += indentCode(parseEnum(node, name, className), 1) + '\n\n'
            else:
                print('Unknown node in class %s: %s' % (className, node.nodeName))
    return text


files = ['QtGuimod.xml', 'QtCoremod.xml']
for filename in files:
    dom = minidom.parse(filename)

    module = dom.firstChild
    assert module.nodeName == 'Module'
    moduleName = module.attributes['name'].value
    print('Module name:', moduleName)

    stats = {}

    with open(moduleName + '.py', 'w') as file:
        for node in module.childNodes:
            if node.nodeType != node.ELEMENT_NODE:
                continue # skip non element nodes
            nodeName = node.nodeName
            stats[nodeName] = stats.setdefault(nodeName, 0) + 1 # stats
            if nodeName == 'Class':
                file.write(parseClass(node) + '\n\n')
            elif nodeName == 'Function':
                file.write(parseFunction(node, node.attributes['name'].value) + '\n\n')
            elif nodeName == 'Member':
                file.write('%s = None # %s member\n\n' % (node.attributes['name'].value, node.attributes['typename'].value))
            else:
                print('Unknown node:', nodeName)

    print('Stats:', stats)



# This file is imported from within the debugger

# Copyright 2014 Sven Brauch
# License: GPL v2+

from kdevpdb import kdevOutputFormatter

import sys

__kdevpython_builtin_locals = locals

try:
    from numpy import ndarray
except:
    class ndarray: pass

# TODO: weakref those, but python can't in general :(
objectTable = {}

def cleanup():
    objectTable.clear()

def obj_to_string(value):
    if type(value) == ndarray:
        value = "numpy.array, shape={0}".format(value.shape)
    value = str(value).replace('\n', r'\n')
    if len(value) > 120:
        value = value[:120] + "..."
    return value

def format_locals(locals_):
    '''Print local variables in a machine-readable format'''
    cleanup()
    for key, value in locals_.items():
        if key == '__kdevpython_debugger_utils':
            continue
        value = obj_to_string(value)
        print("%s => %s" % (key, value))

def format_ptr_children(ptr):
    try:
        expr = objectTable[ptr]
    except KeyError:
        print("Address of object not in memory any more")
        return
    format_object_children(expr)

def format_object_children(expr):
    if type(expr) == set:
        expr = list(expr)

    output = []
    if type(expr) == list or type(expr) == ndarray:
        for i in range(len(expr)):
            identifier = id(expr[i])
            obj = expr[i]
            output.append('ptr:<%s> [%s] => %s' % (identifier, i, obj_to_string(obj)))
            objectTable[identifier] = obj
    elif type(expr) == dict:
        for k, v in expr.items():
            output.append('ptr:<%s> [%s] => %s' % (id(v), obj_to_string(k), obj_to_string(v)))
            objectTable[id(v)] = v
    else:
        for i in dir(expr):
            obj = getattr(expr, i)
            output.append('ptr:<%s> .%s => %s' % (id(obj), i, obj_to_string(obj)))
            objectTable[id(obj)] = obj
    print('\n'.join(output))




#!/usr/bin/env python
# -*- Coding:utf-8 -*-

# Copyright 2013 by Sven Brauch <svenbrauch@googlemail.com>
# License: GNU GPL v2 or later
# The script output is not copyrighted, use it for whatever you want.

# WARNING: This script does things which can cause bad stuff to happen
# to your system in case you execute it on a module which has been
# engineered to be mailicious.
# I thus recommend to run this script as a user with minimal privileges
# (i.e. not as yourself), or even in a chroot.
# In any case, I'm not responsible for any damage caused by this script.

# This script will dump a SINGLE MODULE to a python "header" file.
# It will read one module, and give you one output file.
# Any submodules of the imported object (anything with type "module")
# will be ignored by this script, if you want to dump those,
# you will have to manually (or with a script) generate a directory
# structure and re-run this script.
import re
import traceback

import sys
import types
import inspect
import importlib
import builtins

def debugmsg(message):
    sys.stderr.write(message + "\n")
    sys.stderr.flush()

def structseq_to_py(seq, name="INSERT_NAME"):
    """Turns a "structseq" object to a python pseudoclass."""
    sseq = str(seq)
    sseq = '('.join(sseq.split('(')[1:])
    sseq = ')'.join(sseq.split(')')[:1])
    print("class {0}:".format(name))
    for item in sseq.split(','):
        item = item.strip()
        key, value = item.split('=')
        print(indent("{0} = {1}".format(key, value)))

def indent(code, depth=4):
    code = code.split('\n')
    code = [" "*depth + line for line in code]
    return '\n'.join(code)

def clearIndent(code):
    assert isinstance(code, str)
    code = code.split('\n')
    code = [line.strip() for line in code]
    return '\n'.join(code)

def syntaxValid(code):
    try:
        compile(code, "<no file>", 'exec')
    except SyntaxError:
        return False
    return True

def sanitize(expr):
    assert isinstance(expr, str)
    replace = {
        '*':'', '[':'', ']':'',
        'from':'_from', 'class':'_class', '-':'_', 'lambda':'_lambda', "raise":"_raise",
        '\\':'ESC', ' ':'', "<":'"', ">":'"', "self,":"", "self":"",
        ",,":",", '...':'more_args', '+':"plus"
    }
    result = expr
    for before, after in replace.items():
        result = result.replace(before, after)
    result = re.sub(r"\.\d", "_", result)
    result = result.replace("=,", "=[],").replace("=)", "=[])")
    return result

def strict_sanitize(expr):
    assert isinstance(expr, str)
    expr = sanitize(expr)
    forbidden = ["=()", '(', ')', '"', "'", " ", ",", "|", "%", '#', '{', '}']
    for char in forbidden:
        expr = expr.replace(char, "")
    if len(expr) == 0:
        expr = "_"
    if expr[-1] == '.':
        expr = expr[:-1]
    if expr == ".":
        return "None"
    if len(expr) > 0 and expr[0].isdigit():
        expr = "_" + expr
    return expr

def isSpace(char):
    return char == ' ' or char == '\t'

def removeAtCorner(string, char, direction):
    i = 0
    assert direction in ['<', '>']
    if direction == '>':
        iterator = range(0, len(string))
        def r(s, a): return s[a-1:]
    if direction == '<':
        iterator = [len(string)-x-1 for x in range(0, len(string))]
        def r(s, a): return s[:a+1]

    atBeginning = True
    for i in iterator:
        if isSpace(string[i]) and atBeginning:
            continue
        elif string[i] == char:
            atBeginning = False
        else:
            return r(string, i)
    return str()

likely_substitutions = {
    "integer": "int",
    "string": "str",
    "long": "int",
    "dictionary": "dict",
    "double": "float",
    "scalar": "float",
    "array_like": "ndarray"
}

def do_type_subst(t):
    if t in likely_substitutions:
        return likely_substitutions[t]
    return t

def get_indent(string):
    string = string.split("\n")[0]
    indent = 0
    for char in string:
        if char in [' ', '\t']:
            indent += 1
        else:
            return indent
    return 0

def remove_indent(string):
    if type(string) == str:
        string = string.split("\n")
        max_remove_indent = get_indent(string[0])
        result = ""
        for line in string:
            for offset in range(0, len(line)):
                if line[offset] not in [' ', '\t'] or offset > max_remove_indent:
                    result += line[offset:] + "\n"
                    break
        return result
    else:
        return string

def guess_return_type_from_synopsis(synopsis, root):
    container = ""
    for item in re.finditer("return", synopsis, re.I):
        scan = synopsis[item.start():item.end()+60]
        def apply_container(value):
            if len(container) > 0:
                return "{0}([{1}])".format(container, value)
            else:
                return value
        if "ndarray" in scan.split() or 'array_like' in scan.split() or 'array_type' in scan.split():
            # hack to make "complex ndarray" work properly
            return "ndarray()"
        for word in scan.split():
            if word.find('.') != -1 and word != '...':
                break # end of sentence -- stop
            word = word.replace(',', '')
            if word in ["none", "None"]:
                return "None"
            if word in ["True", "False", "true", "false", "bool", "boolean"]:
                return apply_container("bool()")
            if word in ["dict", "dictionary"]:
                return "dict()"
            if word in ["string", "str", "represenation"]:
                return "str()"
            if word in ["list", "iterable"]:
                container = "list"
                continue
            if word in ["set"]:
                container = "set"
                continue
            if word in ["number", "int", "integer"]:
                return apply_container("int()")
            if word in ["float", "ratio", "fraction"]:
                return apply_container("float()")
            if hasattr(root.module, word) and type(getattr(root.module, word) == type(object)):
                return apply_container(word + "()")
            if word[-1] == "s" and hasattr(root.module, word[:-1]) and type(getattr(root.module, word[:-1]) == type(object)):
                # plural form, "list of ints"
                return apply_container(word[:-1] + "()")
            if hasattr(builtins, word) and type(getattr(builtins, word)) == type(object):
                return apply_container(word + "()")
    if len(container) > 0:
        return container + "()"
    return "None"

def parse_numpy_like_docstring(docstring, funcname, root, needSelfArg=False):
    selflist = ["self"] if needSelfArg else []
    if type(docstring) == str:
        indent = 0
        atLineBeginning = True
        paramListBegin = paramListEnd = False
        returnTypeBegin = returnTypeEnd = False
        atPartBeginning = 2
        returnType = "None"
        for offset in range(0, len(docstring)):
            if docstring[offset] == "\n":
                indent = 0
            if docstring[offset] in [' ', '\t'] and atLineBeginning:
                indent += 1
            else:
                atLineBeginning = False

            if paramListEnd is False:
                if docstring[offset:].startswith("Parameters"):
                    paramListBegin = offset
                if paramListBegin is not False and docstring[offset] == "\n" and atPartBeginning != 0:
                    atPartBeginning -= 1
                if docstring[offset:].startswith("---") and atPartBeginning == 0:
                    paramListEnd = offset
                    break
            if returnTypeEnd == False:
                if docstring[offset:].startswith("Returns"):
                    returnTypeBegin = offset
        relevantPart = docstring[paramListBegin:paramListEnd].split("\n")[2:]
        if returnTypeBegin is not False:
            try:
                line = docstring[returnTypeBegin:].split('\n')[2]
                ret = line.split(' : ')[1]
                if ret.find(' or ') != -1:
                    # unsure return type
                    returnTypes = map(strict_sanitize, [item.split(' ')[0] for item in ret.split(' or ')])
                    returnType = ''.join(["{0}() if False else ".format(do_type_subst(t)) for t in returnTypes[:-1]]) \
                                 + do_type_subst(str(returnTypes[-1])) + "()"
                else:
                    if 'ndarray' in ret.split() or 'array_like' in ret.split() or 'array_type' in ret.split():
                        returnType = "ndarray()"
                    else:
                        returnTypeLine = ret.split(' ')[0].split(',')[0]
                        returnType = do_type_subst(strict_sanitize(returnTypeLine)) + "()"
            except IndexError:
                returnType = guess_return_type_from_synopsis(docstring[returnTypeBegin:], root)
        if len(relevantPart):
            firstIndent = get_indent(relevantPart[0])
            parameter_name_list = []
            for line_index in range(0, len(relevantPart)):
                if get_indent(relevantPart[line_index]) == firstIndent:
                    s = relevantPart[line_index].split(' : ')
                    if len(s) == 2:
                        name = s[0]
                        type_string = s[1]
                        doc_for_param = None # TODO extract this, and display it in some way... or not
                        parameter_name = strict_sanitize(name)
                        if parameter_name.find('...') != -1:
                            parameter_name = 'more'
                        parameter_name = parameter_name.replace('`', '')
                        parameter_name_list.append(parameter_name)
            return ', '.join(selflist + parameter_name_list), do_type_subst(returnType)
        else:
            try:
                firstType = docstring.split("\n")[0].split('.')[-1]
                if firstType.find(funcname) == -1:
                    raise IndexError()
                firstType = firstType.split('->')[0]
                firstType = firstType.split('(')[1:]
                firstType = ')'.join('('.join(firstType).split(')')[:-1])
                paramList = firstType.split(',')
                cleanedParamList = []
                for item in paramList:
                    if item.find('...') == -1:
                        cleanedParamList.append(item)
                return ', '.join(selflist + [strict_sanitize(x) for x in cleanedParamList]), "None"
            except IndexError:
                return "self" if needSelfArg else "", "None"
    else:
        return "self" if needSelfArg else "", "None"

def parse_synopsis(funcdef, original, root, needSelfArg=False):
    """Parse a function description in the following format:
    module.func(param1, param2, [optional_param1 = default1, [optional_param2 = default2]]) -> return_type
    This tries to be as error-prone as possible in order to convert everything into a valid parameter list."""
    # first, take the parts before and after the arrow:
    assert isinstance(funcdef, str)
    funcdef = funcdef.replace("<==>", " -> ")
    s = funcdef.split(' -> ')
    definition = s[0]
    returnType = s[1] if len(s) > 1 else "None"
    # Sometimes, people do fancy stuff in the return type, like "... -> ndarray or None if arg is False"
    # Thus, we only use the first word... well.
    returnType = strict_sanitize(returnType.split(' ')[0])
    if returnType in likely_substitutions:
        returnType = likely_substitutions[returnType]
    if returnType != 'None':
        returnType += "()"
    if returnType == 'None' or returnType == '_()':
        returnType = guess_return_type_from_synopsis(original, root)
    # Okay, now the fun part: parse the parameter list
    inParamList = False
    brackets = 0
    paramList = ""
    for char in definition:
        if char == '(' and not inParamList:
            inParamList = True
        elif char == '(':
            brackets += 1
        if char == ')' and brackets > 0:
            brackets -= 1
        elif char == ')' and inParamList:
            break
        if inParamList and char not in '()':
            paramList += char
    paramList = paramList.split(',')
    resultingParamList = []
    atDefault = False
    for param in paramList:
        defaultValue = None
        # extract the name of the param
        param = param.replace(' ', '').replace('\t', '')
        # check for default values
        if removeAtCorner(param, '[', '>') != removeAtCorner(param, ' ', '>') or param.find('=') != -1:
            # default parameter list starts  or continues with this parameter
            atDefault = True
        if atDefault:
            defaultValue = "None"
            if param.find('=') != -1:
                # default value was provided; clean trailing "[" and "]" chars
                defaultValue = removeAtCorner(removeAtCorner(param.split('=')[1], ']', '<'), '[', '<')
                param = param.split('=')[0]
            if len(str(defaultValue)) == 0 or str(defaultValue).isspace():
                # just write anything, otherwise it's syntactically invalid
                defaultValue = "None"
        if removeAtCorner(param, '[', '<') != removeAtCorner(param, ' ', '<'):
            # default parameter list starts or continues after this parameter
            atDefault = True
        param = strict_sanitize(param)
        if param == '':
            continue
        if defaultValue:
            resultingParamList.append("{0}={1}".format(param, sanitize(defaultValue)))
        else:
            resultingParamList.append(param)
    if needSelfArg:
        # we're in a class, make sure there's a "self"
        if len(resultingParamList) == 0 or ( [resultingParamList[0].find(x) for x in ["self", "cls"]] == [-1, -1] ):
            resultingParamList.insert(0, "self")
    return ', '.join(resultingParamList), returnType


class ModuleDumper:
    def __init__(self, module, startIndent=0, special_hints=dict()):
        self.module = module
        self.code = str()
        self.indentDepth = startIndent
        self.special_hints = special_hints

    def increaseIndent(self):
        self.indentDepth += 4

    def decreaseIndent(self):
        self.indentDepth -= 4
        if self.indentDepth < 0:
            self.indentDepth = 0

    def emit(self, code):
        print(indent(code, self.indentDepth))

    def dump(self):
        debugmsg("Processing module {0}".format(self.module.__name__))
        for member, value in inspect.getmembers(self.module):
            dumper = dumperForObject(value, member, self)
            dumper.dump()

class ScalarDumper:
    def __init__(self, name, value, root):
        self.name = name
        self.value = value
        self.root = root

    def dump(self):
        value = type(self.value).__name__ + "()" if self.value is not None else "None"
        if value == 'module()':
            # numpy fix
            return
        self.root.emit("{0} = {1}".format(self.name, value))

def pick_better_return_value(v1, v2):
    if v1 == "None":
        return v1
    return v2

def pick_better_arglist(s1, s2):
    # return the one with more arguments
    if s1.count(',') > s2.count(','):
        return s1
    return s2

goodValues = [True, False, None]
goodTypes = map(type, [int(), float()])

class FunctionDumper:
    def __init__(self, function, root):
        self.function = function
        self.root = root
        assert isinstance(self.root, ModuleDumper)

    def dump(self):
        try:
            arguments = inspect.getfullargspec(self.function)
            arglist = list()
            for index, argument in enumerate(arguments.args):
                if len(arguments.args) - index - 1 > len(arguments.defaults):
                    # no default value -> normal argument
                    arglist.append(argument)
                else:
                    # there's a default value
                    defaultIndex = index - (len(arguments.args) - len(arguments.defaults))
                    rawDefaultValue = arguments.defaults[defaultIndex]
                    if type(rawDefaultValue) == type(object):
                        defaultValue = strict_sanitize(str(rawDefaultValue)) + "()"
                    elif rawDefaultValue in goodValues or type(rawDefaultValue) in goodTypes:
                        defaultValue = str(rawDefaultValue)
                    else:
                        defaultValue = '"{0}"'.format(str(rawDefaultValue).replace("\n", " "))
                    if len(defaultValue) == 0 or defaultValue.isspace():
                        defaultValue = "None"
                    arglist.append("{0}={1}".format(argument, defaultValue))
            if self.root.indentDepth > 0:
                # we're in a class, make sure there's a "self"
                if len(arglist) == 0 or ( arglist[0].find("self") == -1 and arglist[0].find("cls") == -1 ):
                    arglist.insert(0, "self")
            arglist = ', '.join(arglist)
        except TypeError:
            # not a python function, can't inspect it. try guessing argspec from docstring
            arglist = None
        try:
            docstring = self.function.__doc__.split('\n')[0] if self.function.__doc__ else str()
            try:
                synArglist, returnValue = parse_synopsis(docstring, str(self.function.__doc__), self.root,
                                                         self.root.indentDepth > 0)
            except Exception as e:
                debugmsg(format(e))
            try:
                synArglist2, returnValue2 = parse_numpy_like_docstring(str(self.function.__doc__),
                                                                       self.function.__name__, self.root,
                                                                       self.root.indentDepth > 0)
            except Exception as e:
                debugmsg(format(e))
            synArglist = pick_better_arglist(synArglist, synArglist2)
            returnValue = pick_better_return_value(returnValue, returnValue2)
        except Exception as e:
            debugmsg("  Warning: Function argument extraction failed: {0}".format(e))
            debugmsg("   * Traceback follows, but the error was ignored since it is not fatal.")
            traceback.print_exc(file=sys.stderr)
            synArglist = ""
            returnValue = "None"
        if docstring.find("Not implemented (virtual attribute)") != -1:
            # numpy hack
            return
        if arglist is None:
            arglist = synArglist
        try:
            funcname = self.function.__name__
        except:
            return
        if funcname in self.root.special_hints:
            hints = self.root.special_hints[funcname]
            if "returns" in hints:
                returnValue = hints["returns"]
        if funcname[0].isdigit():
            funcname = '_' + funcname
        if funcname.startswith('__'):
            return
        self.root.emit("def {0}({1}):".format(strict_sanitize(funcname), arglist))
        self.root.increaseIndent()
        self.root.emit('"""{0}"""'.format(str(self.function.__doc__).replace('"""', '___')))
        self.root.emit("return {0}".format(returnValue))
        self.root.decreaseIndent()

class ClassDumper:
    def __init__(self, klass, root):
        self.klass = klass
        self.root = root
        assert isinstance(self.root, ModuleDumper)

    def dump(self):
        debugmsg("Generating documentation for class {0}".format(self.klass.__name__))
        self.root.emit("class {0}:".format(self.klass.__name__))
        self.root.increaseIndent()
        for member, value in inspect.getmembers(self.klass):
            if type(value) == type:
                continue
            dumper = dumperForObject(value, member, self.root)
            dumper.dump()
        self.root.decreaseIndent()

dumpers = {
    types.FunctionType: FunctionDumper,
    types.BuiltinFunctionType: FunctionDumper,
    types.BuiltinMethodType: FunctionDumper,
    type: ClassDumper
}
try:
    dumpers[types.ClassType] = ClassDumper # python 2
except:
    pass

def dumperForObject(object, memberName, root):
    try:
        return dumpers[type(object)](object, root)
    except:
        if hasattr(object, "__call__"):
            return FunctionDumper(object, root);
        return ScalarDumper(memberName, object, root)

if __name__ == '__main__':
    try:
        argscount = len(sys.argv)
        for arg in range(1, argscount-2):
            sys.path.insert(1, sys.argv[arg])
        dumper = ModuleDumper(importlib.import_module(sys.argv[-1]))
    except IndexError:
        debugmsg("Usage: introspect.py <python_module_name>")
        exit(1)
    dumper.dump()
    debugmsg("All done -- looks good so far.")



#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":platform: Unix
:synopsis: The password database (getpwnam() and friends).


This module provides access to the Unix user account and password database.  It
is available on all Unix versions.

Password database entries are reported as a tuple-like object, whose attributes
correspond to the members of the ``passwd`` structure (Attribute field below,
see ``<pwd.h>``):

+-------+---------------+-----------------------------+
| Index | Attribute     | Meaning                     |
+=======+===============+=============================+
| 0     | ``pw_name``   | Login name                  |
+-------+---------------+-----------------------------+
| 1     | ``pw_passwd`` | Optional encrypted password |
+-------+---------------+-----------------------------+
| 2     | ``pw_uid``    | Numerical user ID           |
+-------+---------------+-----------------------------+
| 3     | ``pw_gid``    | Numerical group ID          |
+-------+---------------+-----------------------------+
| 4     | ``pw_gecos``  | User name or comment field  |
+-------+---------------+-----------------------------+
| 5     | ``pw_dir``    | User home directory         |
+-------+---------------+-----------------------------+
| 6     | ``pw_shell``  | User command interpreter    |
+-------+---------------+-----------------------------+

The uid and gid items are integers, all others are strings. :exc:`KeyError` is
raised if the entry asked for cannot be found.

"""
def getpwuid(uid):
	"""
	Return the password database entry for the given numeric user ID.
	
	
	"""
	pass
	
def getpwnam(name):
	"""
	Return the password database entry for the given user name.
	
	
	"""
	pass
	
def getpwall():
	"""
	Return a list of all available password database entries, in arbitrary order.
	
	
	"""
	pass
	



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.5
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(294, 133)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.pushButton = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton.setObjectName("pushButton")
        self.verticalLayout.addWidget(self.pushButton)
        self.progressBar = QtWidgets.QProgressBar(self.centralwidget)
        self.progressBar.setProperty("value", 24)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 294, 29))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionQuit = QtWidgets.QAction(MainWindow)
        self.actionQuit.setObjectName("actionQuit")
        self.menuFile.addAction(self.actionQuit)
        self.menubar.addAction(self.menuFile.menuAction())

        self.retranslateUi(MainWindow)
        self.actionQuit.triggered.connect(MainWindow.close)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.pushButton.setText(_translate("MainWindow", "Click Me!"))
        self.menuFile.setTitle(_translate("MainWindow", "Fi&le"))
        self.actionQuit.setText(_translate("MainWindow", "&Quit"))

